window.Gleam.initSearch([{"doc":"sketch_lustre_experimental","title":"sketch_lustre_experimental","content":"# Sketch Lustre Experimental\n\n&gt; In case you&#39;re here and don&#39;t know Sketch, take a look at\n&gt; [`sketch` package](https://hexdocs.pm/sketch)!\n\n## Setup\n\nIf you&#39;re here, it means you&#39;re ready to test the future of Sketch Lustre! Be\ncareful, unexpected things can happen. `sketch_lustre_experimental` exposes one\nentrypoint, `sketch/lustre/experimental`, containing everything needed to get\nstarted.\n\n```gleam\n// main.gleam\nimport lustre\nimport sketch\nimport sketch/lustre/experimental as sketch_lustre\n\npub fn main() {\n  // Initialise the cache. Two strategies can be used. Ephemeral caches are designed as throw-away caches.\n  let assert Ok(_) = sketch.stylesheet(strategy: sketch.Ephemeral)\n  // Generate the partial view function, compatible with Lustre&#39;s runtime.\n  lustre.simple(init, update, view)\n  // And voilà!\n  |&gt; lustre.start(&quot;#app&quot;, Nil)\n}\n\nfn view(model) {\n  // Add the sketch CSS generation &quot;view middleware&quot;.\n  use &lt;- sketch_lustre.render(in: [sketch_lustre.node()])\n  // Run your actual view function.\n  my_view(model)\n}\n```\n\n## Usage\n\n`sketch_lustre_experimental` exposes two modules to help you build your site,\nsimilarly to Lustre: `sketch/lustre/experimental/element` and\n`sketch/lustre/experimental/element/html`. The first one let you use raw element\ngeneration and exposes the Lustre `Element(msg)` type. Every time you need\nelements helpers, i.e. `element`, `fragment`, or even `keyed`, use directly\n`lustre/element` module.\n\nNB: all elements can be generated using the correct function, or using its\n&quot;underscored&quot; version. In the second case, Sketch Lustre behaves _exactly_ like\nLustre, and will not add another class. This is helpful when you want to use a\nsimple node, without any class linked on it.\n\n```gleam\nimport sketch/css\nimport sketch/css/length.{px}\nimport sketch/lustre/experimental/element\nimport sketch/lustre/experimental/element/html\n\nfn main_style() {\n  css.class([\n    css.background(&quot;red&quot;),\n    css.font_size(px(16)),\n  ])\n}\n\nfn view(model: Int) {\n  html.div(main_style(), [], [\n    html.div_([], [\n      html.text(int.to_string(model)),\n    ]),\n  ])\n}\n```\n\nAnd you&#39;re done! Enjoy your Lustre app, Sketch-enhanced!\n\n## Final notes\n\n### On Sketch Lustre Experimental Element\n\nA Sketch `Element(msg)` is a Lustre `Element(msg)`, with class name directly\nlinked on it. You don&#39;t need anything to do to get a\n`lustre/element.Element(msg)`. This also means you can use any Lustre\n`Element(msg)` function you already have.\n\n### Usage with Shadow DOM\n\nIn browser, Sketch can work with a Shadow DOM, in order to hide the compiled\nstyles from the rest of the application. With a proper shadow root (represented\nas a `Dynamic` in Gleam), you can use\n[`sketch/lustre/experimental.shadow()`](https://hexdocs.pm/sketch_lustre/sketch/lustre.html#shadow)\nto render a stylesheet in the shadow root directly. In the same way you can\ninitialize the cache to render in document or in a `style` node, you can use a\nshadow root to paint styles in your application!\n","url":"index.html"},{"doc":"sketch/lustre/experimental","title":"Container","content":"pub opaque type Container\n Location to output the generated CSS. Every `render` or `ssr` call expect\n one or more containers, and dump the generated CSS inside. Containers can\n be created with [`document()`](#document), [`node()`](#node) or\n [`shadow()`](#shadow).\n\nSynonyms:\nsketch/lustre/experimental.Container\nsketch/lustre/experimental Container","url":"sketch/lustre/experimental.html#Container"},{"doc":"sketch/lustre/experimental","title":"node","content":"pub fn node() -&gt; Container\n Create a container in the window document. Create a `CSSStyleSheet` and\n updates the content directly inside. \\\n Because `document` is only accessible in the browser, that function cannot\n be called on Erlang target.\n Create a container in a Shadow Root. Create a `CSSStyleSheet` and\n updates the content directly inside. \\\n Because `document` is only accessible in the browser, that function cannot\n be called on Erlang target.\n Create a container directly in the DOM. CSS will be put directly in the\n elements tree, in a `&lt;style&gt;` tag.\nSynonyms:\nsketch/lustre/experimental.node\nsketch/lustre/experimental node","url":"sketch/lustre/experimental.html#node"},{"doc":"sketch/lustre/experimental","title":"render","content":"pub fn render(\n  in outputs: List(Container),\n  after view: fn() -&gt; Element(a),\n) -&gt; Element(a)\n Use `render` as a view middleware. Like in Wisp, `sketch_lustre_experimental`\n adopts the middleware philosophy in Lustre, and allows you to call `render`\n directly in your view function, by using `use`. No need to wrap your view\n function.\n\n \n import lustre\n import lustre/element\n import sketch\n import sketch/lustre/experimental as sketch_lustre\n import sketch/lustre/experimental/element/html\n\n pub fn main() {\n   let assert Ok(stylesheet) = sketch.stylesheet(strategy: sketch.Persistent)\n   let assert Ok(_) = sketch_lustre.setup(stylesheet)\n   lustre.simple(init, update, view(_, stylesheet))\n   |&gt; lustre.start(&quot;#root&quot;, Nil)\n }\n\n fn view(model: model, stylesheet: sketch.StyleSheet) -&gt; element.Element(msg) {\n   use &lt;- skech_lustre.render(stylesheet, in: [sketch_lustre.node()])\n   html.div([], [])\n }\n \nSynonyms:\nsketch/lustre/experimental.render\nsketch/lustre/experimental render","url":"sketch/lustre/experimental.html#render"},{"doc":"sketch/lustre/experimental","title":"setup","content":"pub fn setup(stylesheet: StyleSheet) -&gt; Result(StyleSheet, Nil)\n Setup the StyleSheet to use across your application. One stylesheet must be\n set in your entire application. `setup` should be called once at startup.\n You can call `setup` any time you want to reset your stylesheet. \\\n Because of performance reasons and race conditions, non-persistent\n stylesheets will fail to initialize the package. Always use a `Persistent`\n stylesheet with `sketch_lustre_experimental`.\n\n \n pub fn main() {\n   let assert Ok(stylesheet) = sketch.stylesheet(strategy: sketch.Persistent)\n   let assert Ok(_) = sketch_lustre.setup(stylesheet)\n   // The following code goes there.\n }\n \nSynonyms:\nsketch/lustre/experimental.setup\nsketch/lustre/experimental setup","url":"sketch/lustre/experimental.html#setup"},{"doc":"sketch/lustre/experimental","title":"ssr","content":"pub fn ssr(view: fn() -&gt; Element(a)) -&gt; Element(a)\n Use `ssr` as a view middleware. Like in Wisp, `sketch_lustre_experimental`\n adopts the middleware philosophy in Lustre, and allows you to call `ssr`\n directly in your view function, by using `use`. No need to wrap your view\n function.\n\n \n import gleam/bytes_tree\n import gleam/http/response\n import lustre\n import lustre/element\n import mist\n import sketch\n import sketch/lustre/experimental as sketch_lustre\n import sketch/lustre/experimental/element/html\n import wisp\n\n pub fn main() {\n   let assert Ok(stylesheet) = sketch.stylesheet(strategy: sketch.Persistent)\n   let assert Ok(_) = sketch_lustre.setup(stylesheet)\n   let assert Ok(_) =\n     fn(_) { greet(stylesheet) }\n     |&gt; mist.new()\n     |&gt; mist.port(1234)\n     |&gt; mist.start_http()\n   process.sleep_forever()\n }\n\n pub fn greet(stylesheet: sketch.StyleSheet) -&gt; wisp.Response {\n   view(model, stylesheet)\n   |&gt; element.to_document_string\n   |&gt; bytes_tree.to_document_string\n   |&gt; mist.Bytes\n   |&gt; response.set_body(response.new(200), _)\n }\n\n fn view(model: model, stylesheet: sketch.StyleSheet) -&gt; element.Element(msg) {\n   use &lt;- skech_lustre.ssr(stylesheet)\n   html.div([], [])\n }\n \nSynonyms:\nsketch/lustre/experimental.ssr\nsketch/lustre/experimental ssr","url":"sketch/lustre/experimental.html#ssr"},{"doc":"sketch/lustre/experimental","title":"sketch/lustre/experimental","content":"","url":"sketch/lustre/experimental.html"},{"doc":"sketch/lustre/experimental/element","title":"Element","content":"pub type Element(msg) =\n  el.Element(msg)\n Alias for `lustre/element.Element`. \\\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#Element)\n\nSynonyms:\nsketch/lustre/experimental/element.Element\nsketch/lustre/experimental/element Element","url":"sketch/lustre/experimental/element.html#Element"},{"doc":"sketch/lustre/experimental/element","title":"fragment","content":"pub const fragment: fn(List(Element(a))) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#fragment)\nSynonyms:\nsketch/lustre/experimental/element.fragment\nsketch/lustre/experimental/element fragment","url":"sketch/lustre/experimental/element.html#fragment"},{"doc":"sketch/lustre/experimental/element","title":"keyed","content":"pub const keyed: fn(\n  fn(List(Element(a))) -&gt; Element(a),\n  List(#(String, Element(a))),\n) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#keyed)\nSynonyms:\nsketch/lustre/experimental/element.keyed\nsketch/lustre/experimental/element keyed","url":"sketch/lustre/experimental/element.html#keyed"},{"doc":"sketch/lustre/experimental/element","title":"map","content":"pub const map: fn(Element(a), fn(a) -&gt; b) -&gt; Element(b)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#map)\nSynonyms:\nsketch/lustre/experimental/element.map\nsketch/lustre/experimental/element map","url":"sketch/lustre/experimental/element.html#map"},{"doc":"sketch/lustre/experimental/element","title":"none","content":"pub const none: fn() -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#none)\nSynonyms:\nsketch/lustre/experimental/element.none\nsketch/lustre/experimental/element none","url":"sketch/lustre/experimental/element.html#none"},{"doc":"sketch/lustre/experimental/element","title":"text","content":"pub const text: fn(String) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#text)\nSynonyms:\nsketch/lustre/experimental/element.text\nsketch/lustre/experimental/element text","url":"sketch/lustre/experimental/element.html#text"},{"doc":"sketch/lustre/experimental/element","title":"class_name","content":"pub fn class_name(class: Class) -&gt; String\n Generate a class name from a `Class`, using the `StyleSheet` injected\n in the environment.\nSynonyms:\nsketch/lustre/experimental/element.class_name\nsketch/lustre/experimental/element class_name","url":"sketch/lustre/experimental/element.html#class_name"},{"doc":"sketch/lustre/experimental/element","title":"element","content":"pub fn element(\n  tag tag: String,\n  class class: Class,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#element)\nSynonyms:\nsketch/lustre/experimental/element.element\nsketch/lustre/experimental/element element","url":"sketch/lustre/experimental/element.html#element"},{"doc":"sketch/lustre/experimental/element","title":"element_","content":"pub fn element_(\n  tag tag: String,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#element)\nSynonyms:\nsketch/lustre/experimental/element.element_\nsketch/lustre/experimental/element element_","url":"sketch/lustre/experimental/element.html#element_"},{"doc":"sketch/lustre/experimental/element","title":"namespaced","content":"pub fn namespaced(\n  tag tag: String,\n  namespace namespace: String,\n  class class: Class,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#namespaced)\nSynonyms:\nsketch/lustre/experimental/element.namespaced\nsketch/lustre/experimental/element namespaced","url":"sketch/lustre/experimental/element.html#namespaced"},{"doc":"sketch/lustre/experimental/element","title":"namespaced_","content":"pub fn namespaced_(\n  tag tag: String,\n  namespace namespace: String,\n  attributes attributes: List(Attribute(a)),\n  children children: List(Element(a)),\n) -&gt; Element(a)\n [Lustre Documentation](https://hexdocs.pm/lustre/lustre/element.html#namespaced)\nSynonyms:\nsketch/lustre/experimental/element.namespaced_\nsketch/lustre/experimental/element namespaced_","url":"sketch/lustre/experimental/element.html#namespaced_"},{"doc":"sketch/lustre/experimental/element","title":"sketch/lustre/experimental/element","content":" This module is a drop-in replacement for `lustre/element`. Just\n use the new functions, and everything will automagically be styled.","url":"sketch/lustre/experimental/element.html"},{"doc":"sketch/lustre/experimental/element/html","title":"a","content":"pub fn a(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;a&gt;` HTML element (or anchor element), with [its `href` attribute](https://developer.mozilla.org/docs/Web/HTML/Element/a#href),\n creates a hyperlink to web pages, files, email addresses, locations in the\n same page, or anything else a URL can address.\n\n Content within each `&lt;a&gt;` should indicate the link&#39;s destination. If the\n `href` attribute is present, pressing the enter key while focused on the\n `&lt;a&gt;` element will activate it.\n\n You can use [`modem`](https://hexdocs.pm/modem/) to manage internal linking\n in your Lustre application.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/a)\nSynonyms:\nsketch/lustre/experimental/element/html.a\nsketch/lustre/experimental/element/html a","url":"sketch/lustre/experimental/element/html.html#a"},{"doc":"sketch/lustre/experimental/element/html","title":"a_","content":"pub fn a_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;a&gt;` HTML element (or anchor element), with [its `href` attribute](https://developer.mozilla.org/docs/Web/HTML/Element/a#href),\n creates a hyperlink to web pages, files, email addresses, locations in the\n same page, or anything else a URL can address.\n\n Content within each `&lt;a&gt;` should indicate the link&#39;s destination. If the\n `href` attribute is present, pressing the enter key while focused on the\n `&lt;a&gt;` element will activate it.\n\n You can use [`modem`](https://hexdocs.pm/modem/) to manage internal linking\n in your Lustre application.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/a)\nSynonyms:\nsketch/lustre/experimental/element/html.a_\nsketch/lustre/experimental/element/html a_","url":"sketch/lustre/experimental/element/html.html#a_"},{"doc":"sketch/lustre/experimental/element/html","title":"abbr","content":"pub fn abbr(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;abbr&gt;` HTML element represents an abbreviation or acronym.\n\n When including an abbreviation or acronym, provide a full expansion of the\n term in plain text on first use, along with the `&lt;abbr&gt;` to mark up the\n abbreviation. This informs the user what the abbreviation or acronym means.\n\n The optional `title` attribute can provide an expansion for the abbreviation\n or acronym when a full expansion is not present. This provides a hint to\n user agents on how to announce/display the content while informing all users\n what the abbreviation means. If present, `title` must contain this full\n description and nothing else.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/abbr)\nSynonyms:\nsketch/lustre/experimental/element/html.abbr\nsketch/lustre/experimental/element/html abbr","url":"sketch/lustre/experimental/element/html.html#abbr"},{"doc":"sketch/lustre/experimental/element/html","title":"abbr_","content":"pub fn abbr_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;abbr&gt;` HTML element represents an abbreviation or acronym.\n\n When including an abbreviation or acronym, provide a full expansion of the\n term in plain text on first use, along with the `&lt;abbr&gt;` to mark up the\n abbreviation. This informs the user what the abbreviation or acronym means.\n\n The optional `title` attribute can provide an expansion for the abbreviation\n or acronym when a full expansion is not present. This provides a hint to\n user agents on how to announce/display the content while informing all users\n what the abbreviation means. If present, `title` must contain this full\n description and nothing else.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/abbr)\nSynonyms:\nsketch/lustre/experimental/element/html.abbr_\nsketch/lustre/experimental/element/html abbr_","url":"sketch/lustre/experimental/element/html.html#abbr_"},{"doc":"sketch/lustre/experimental/element/html","title":"address","content":"pub fn address(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;address&gt;` HTML element indicates that the enclosed HTML provides\n contact information for a person or people, or for an organization.\n\n The contact information provided by an `&lt;address&gt;` element&#39;s contents can\n take whatever form is appropriate for the context, and may include any type\n  of contact information that is needed, such as a physical address, URL,\n  email address, phone number, social media handle, geographic coordinates,\n and so forth. The `&lt;address&gt;` element should include the name of the person,\n people, or organization to which the contact information refers.\n\n `&lt;address&gt;` can be used in a variety of contexts, such as providing a\n business&#39;s contact information in the page header, or indicating the author\n of an article by including an `&lt;address&gt;` element within the `&lt;article&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/address)\nSynonyms:\nsketch/lustre/experimental/element/html.address\nsketch/lustre/experimental/element/html address","url":"sketch/lustre/experimental/element/html.html#address"},{"doc":"sketch/lustre/experimental/element/html","title":"address_","content":"pub fn address_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;address&gt;` HTML element indicates that the enclosed HTML provides\n contact information for a person or people, or for an organization.\n\n The contact information provided by an `&lt;address&gt;` element&#39;s contents can\n take whatever form is appropriate for the context, and may include any type\n  of contact information that is needed, such as a physical address, URL,\n  email address, phone number, social media handle, geographic coordinates,\n and so forth. The `&lt;address&gt;` element should include the name of the person,\n people, or organization to which the contact information refers.\n\n `&lt;address&gt;` can be used in a variety of contexts, such as providing a\n business&#39;s contact information in the page header, or indicating the author\n of an article by including an `&lt;address&gt;` element within the `&lt;article&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/address)\nSynonyms:\nsketch/lustre/experimental/element/html.address_\nsketch/lustre/experimental/element/html address_","url":"sketch/lustre/experimental/element/html.html#address_"},{"doc":"sketch/lustre/experimental/element/html","title":"area","content":"pub fn area(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;area&gt;` HTML element defines an area inside an image map that has\n predefined clickable areas. An image map allows geometric areas on an\n image to be associated with hypertext links.\n\n This element is used only within a `&lt;map&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/area)\nSynonyms:\nsketch/lustre/experimental/element/html.area\nsketch/lustre/experimental/element/html area","url":"sketch/lustre/experimental/element/html.html#area"},{"doc":"sketch/lustre/experimental/element/html","title":"area_","content":"pub fn area_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;area&gt;` HTML element defines an area inside an image map that has\n predefined clickable areas. An image map allows geometric areas on an\n image to be associated with hypertext links.\n\n This element is used only within a `&lt;map&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/area)\nSynonyms:\nsketch/lustre/experimental/element/html.area_\nsketch/lustre/experimental/element/html area_","url":"sketch/lustre/experimental/element/html.html#area_"},{"doc":"sketch/lustre/experimental/element/html","title":"article","content":"pub fn article(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;article&gt;` HTML element represents a self-contained composition in a\n document, page, application, or site, which is intended to be independently\n distributable or reusable (e.g., in syndication). Examples include: a forum\n post, a magazine or newspaper article, or a blog entry, a product card, a\n user-submitted comment, an interactive widget or gadget, or any other\n independent item of content.\n\n A given document can have multiple articles in it; for example, on a blog\n that shows the text of each article one after another as the reader scrolls,\n each post would be contained in an `&lt;article&gt;` element, possibly with one\n or more `&lt;section&gt;`s within.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/article)\nSynonyms:\nsketch/lustre/experimental/element/html.article\nsketch/lustre/experimental/element/html article","url":"sketch/lustre/experimental/element/html.html#article"},{"doc":"sketch/lustre/experimental/element/html","title":"article_","content":"pub fn article_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;article&gt;` HTML element represents a self-contained composition in a\n document, page, application, or site, which is intended to be independently\n distributable or reusable (e.g., in syndication). Examples include: a forum\n post, a magazine or newspaper article, or a blog entry, a product card, a\n user-submitted comment, an interactive widget or gadget, or any other\n independent item of content.\n\n A given document can have multiple articles in it; for example, on a blog\n that shows the text of each article one after another as the reader scrolls,\n each post would be contained in an `&lt;article&gt;` element, possibly with one\n or more `&lt;section&gt;`s within.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/article)\nSynonyms:\nsketch/lustre/experimental/element/html.article_\nsketch/lustre/experimental/element/html article_","url":"sketch/lustre/experimental/element/html.html#article_"},{"doc":"sketch/lustre/experimental/element/html","title":"aside","content":"pub fn aside(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;aside&gt;` HTML element represents a portion of a document whose content\n is only indirectly related to the document&#39;s main content. Asides are f\n requently presented as sidebars or call-out boxes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/aside)\nSynonyms:\nsketch/lustre/experimental/element/html.aside\nsketch/lustre/experimental/element/html aside","url":"sketch/lustre/experimental/element/html.html#aside"},{"doc":"sketch/lustre/experimental/element/html","title":"aside_","content":"pub fn aside_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;aside&gt;` HTML element represents a portion of a document whose content\n is only indirectly related to the document&#39;s main content. Asides are f\n requently presented as sidebars or call-out boxes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/aside)\nSynonyms:\nsketch/lustre/experimental/element/html.aside_\nsketch/lustre/experimental/element/html aside_","url":"sketch/lustre/experimental/element/html.html#aside_"},{"doc":"sketch/lustre/experimental/element/html","title":"audio","content":"pub fn audio(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;audio&gt;` HTML element is used to embed sound content in documents. It\n may contain one or more audio sources, represented using the src attribute\n or the `&lt;source&gt;` element: the browser will choose the most suitable one. It\n can also be the destination for streamed media, using a `MediaStream`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/audio)\nSynonyms:\nsketch/lustre/experimental/element/html.audio\nsketch/lustre/experimental/element/html audio","url":"sketch/lustre/experimental/element/html.html#audio"},{"doc":"sketch/lustre/experimental/element/html","title":"audio_","content":"pub fn audio_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;audio&gt;` HTML element is used to embed sound content in documents. It\n may contain one or more audio sources, represented using the src attribute\n or the `&lt;source&gt;` element: the browser will choose the most suitable one. It\n can also be the destination for streamed media, using a `MediaStream`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/audio)\nSynonyms:\nsketch/lustre/experimental/element/html.audio_\nsketch/lustre/experimental/element/html audio_","url":"sketch/lustre/experimental/element/html.html#audio_"},{"doc":"sketch/lustre/experimental/element/html","title":"b","content":"pub fn b(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;b&gt;` HTML element is used to draw the reader&#39;s attention to the\n element&#39;s contents, which are not otherwise granted special importance.\n This was formerly known as the Boldface element, and most browsers still\n draw the text in boldface. However, you should not use `&lt;b&gt;` for styling text\n or granting importance. If you wish to create boldface text, you should\n use the CSS `font-weight` property. If you wish to indicate an element is\n of special importance, you should use the `&lt;strong&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/b)\nSynonyms:\nsketch/lustre/experimental/element/html.b\nsketch/lustre/experimental/element/html b","url":"sketch/lustre/experimental/element/html.html#b"},{"doc":"sketch/lustre/experimental/element/html","title":"b_","content":"pub fn b_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;b&gt;` HTML element is used to draw the reader&#39;s attention to the\n element&#39;s contents, which are not otherwise granted special importance.\n This was formerly known as the Boldface element, and most browsers still\n draw the text in boldface. However, you should not use `&lt;b&gt;` for styling text\n or granting importance. If you wish to create boldface text, you should\n use the CSS `font-weight` property. If you wish to indicate an element is\n of special importance, you should use the `&lt;strong&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/b)\nSynonyms:\nsketch/lustre/experimental/element/html.b_\nsketch/lustre/experimental/element/html b_","url":"sketch/lustre/experimental/element/html.html#b_"},{"doc":"sketch/lustre/experimental/element/html","title":"base","content":"pub fn base(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;base&gt;` HTML element specifies the base URL to use for all relative\n URLs in a document. There can be only one `&lt;base&gt;` element in a document.\n\n A document&#39;s used base URL can be accessed by scripts with `Node.baseURI`.\n If the document has no `&lt;base&gt;` elements, then `baseURI` defaults to\n `location.href`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/base)\nSynonyms:\nsketch/lustre/experimental/element/html.base\nsketch/lustre/experimental/element/html base","url":"sketch/lustre/experimental/element/html.html#base"},{"doc":"sketch/lustre/experimental/element/html","title":"bdi","content":"pub fn bdi(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;bdi&gt;` HTML element tells the browser&#39;s bidirectional algorithm to\n treat the text it contains in isolation from its surrounding text. It&#39;s\n particularly useful when a website dynamically inserts some text and\n doesn&#39;t know the directionality of the text being inserted.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/bdi)\nSynonyms:\nsketch/lustre/experimental/element/html.bdi\nsketch/lustre/experimental/element/html bdi","url":"sketch/lustre/experimental/element/html.html#bdi"},{"doc":"sketch/lustre/experimental/element/html","title":"bdi_","content":"pub fn bdi_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;bdi&gt;` HTML element tells the browser&#39;s bidirectional algorithm to\n treat the text it contains in isolation from its surrounding text. It&#39;s\n particularly useful when a website dynamically inserts some text and\n doesn&#39;t know the directionality of the text being inserted.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/bdi)\nSynonyms:\nsketch/lustre/experimental/element/html.bdi_\nsketch/lustre/experimental/element/html bdi_","url":"sketch/lustre/experimental/element/html.html#bdi_"},{"doc":"sketch/lustre/experimental/element/html","title":"bdo","content":"pub fn bdo(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;bdo&gt;` HTML element overrides the current directionality of text, so\n that the text within is rendered in a different direction.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/bdo)\nSynonyms:\nsketch/lustre/experimental/element/html.bdo\nsketch/lustre/experimental/element/html bdo","url":"sketch/lustre/experimental/element/html.html#bdo"},{"doc":"sketch/lustre/experimental/element/html","title":"bdo_","content":"pub fn bdo_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;bdo&gt;` HTML element overrides the current directionality of text, so\n that the text within is rendered in a different direction.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/bdo)\nSynonyms:\nsketch/lustre/experimental/element/html.bdo_\nsketch/lustre/experimental/element/html bdo_","url":"sketch/lustre/experimental/element/html.html#bdo_"},{"doc":"sketch/lustre/experimental/element/html","title":"blockquote","content":"pub fn blockquote(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;blockquote&gt;` HTML element indicates that the enclosed text is an\n extended quotation. Usually, this is rendered visually by indentation.\n A URL for the source of the quotation may be given using the cite attribute,\n while a text representation of the source can be given using the `&lt;cite&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/blockquote)\nSynonyms:\nsketch/lustre/experimental/element/html.blockquote\nsketch/lustre/experimental/element/html blockquote","url":"sketch/lustre/experimental/element/html.html#blockquote"},{"doc":"sketch/lustre/experimental/element/html","title":"blockquote_","content":"pub fn blockquote_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;blockquote&gt;` HTML element indicates that the enclosed text is an\n extended quotation. Usually, this is rendered visually by indentation.\n A URL for the source of the quotation may be given using the cite attribute,\n while a text representation of the source can be given using the `&lt;cite&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/blockquote)\nSynonyms:\nsketch/lustre/experimental/element/html.blockquote_\nsketch/lustre/experimental/element/html blockquote_","url":"sketch/lustre/experimental/element/html.html#blockquote_"},{"doc":"sketch/lustre/experimental/element/html","title":"body","content":"pub fn body(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;body&gt;` HTML element represents the content of an HTML document.\n There can be only one `&lt;body&gt;` element in a document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/body)\nSynonyms:\nsketch/lustre/experimental/element/html.body\nsketch/lustre/experimental/element/html body","url":"sketch/lustre/experimental/element/html.html#body"},{"doc":"sketch/lustre/experimental/element/html","title":"body_","content":"pub fn body_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;body&gt;` HTML element represents the content of an HTML document.\n There can be only one `&lt;body&gt;` element in a document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/body)\nSynonyms:\nsketch/lustre/experimental/element/html.body_\nsketch/lustre/experimental/element/html body_","url":"sketch/lustre/experimental/element/html.html#body_"},{"doc":"sketch/lustre/experimental/element/html","title":"br","content":"pub fn br(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;br&gt;` HTML element produces a line break in text (carriage-return).\n It is useful for writing a poem or an address, where the division of\n lines is significant.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/br)\nSynonyms:\nsketch/lustre/experimental/element/html.br\nsketch/lustre/experimental/element/html br","url":"sketch/lustre/experimental/element/html.html#br"},{"doc":"sketch/lustre/experimental/element/html","title":"br_","content":"pub fn br_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;br&gt;` HTML element produces a line break in text (carriage-return).\n It is useful for writing a poem or an address, where the division of\n lines is significant.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/br)\nSynonyms:\nsketch/lustre/experimental/element/html.br_\nsketch/lustre/experimental/element/html br_","url":"sketch/lustre/experimental/element/html.html#br_"},{"doc":"sketch/lustre/experimental/element/html","title":"button","content":"pub fn button(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;button&gt;` HTML element is an interactive element activated by a user\n with a mouse, keyboard, finger, voice command, or other assistive technology.\n Once activated, it then performs an action, such as submitting a form or\n opening a dialog.\n\n By default, HTML buttons are presented in a style resembling the platform\n the user agent runs on, but you can change buttons&#39; appearance with CSS.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/button)\nSynonyms:\nsketch/lustre/experimental/element/html.button\nsketch/lustre/experimental/element/html button","url":"sketch/lustre/experimental/element/html.html#button"},{"doc":"sketch/lustre/experimental/element/html","title":"button_","content":"pub fn button_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;button&gt;` HTML element is an interactive element activated by a user\n with a mouse, keyboard, finger, voice command, or other assistive technology.\n Once activated, it then performs an action, such as submitting a form or\n opening a dialog.\n\n By default, HTML buttons are presented in a style resembling the platform\n the user agent runs on, but you can change buttons&#39; appearance with CSS.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/button)\nSynonyms:\nsketch/lustre/experimental/element/html.button_\nsketch/lustre/experimental/element/html button_","url":"sketch/lustre/experimental/element/html.html#button_"},{"doc":"sketch/lustre/experimental/element/html","title":"canvas","content":"pub fn canvas(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n Use the HTML `&lt;canvas&gt;` element with either the\n [canvas scripting API](https://developer.mozilla.org/docs/Web/API/Canvas_API) or the\n [WebGL API](https://developer.mozilla.org/docs/Web/API/WebGL_API)\n to draw graphics and animations.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/canvas)\nSynonyms:\nsketch/lustre/experimental/element/html.canvas\nsketch/lustre/experimental/element/html canvas","url":"sketch/lustre/experimental/element/html.html#canvas"},{"doc":"sketch/lustre/experimental/element/html","title":"canvas_","content":"pub fn canvas_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n Use the HTML `&lt;canvas&gt;` element with either the\n [canvas scripting API](https://developer.mozilla.org/docs/Web/API/Canvas_API) or the\n [WebGL API](https://developer.mozilla.org/docs/Web/API/WebGL_API)\n to draw graphics and animations.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/canvas)\nSynonyms:\nsketch/lustre/experimental/element/html.canvas_\nsketch/lustre/experimental/element/html canvas_","url":"sketch/lustre/experimental/element/html.html#canvas_"},{"doc":"sketch/lustre/experimental/element/html","title":"caption","content":"pub fn caption(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;caption&gt;` HTML element specifies the caption (or title) of a table, p\n roviding the table an [accessible description](https://developer.mozilla.org/docs/Glossary/Accessible_description).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/caption)\nSynonyms:\nsketch/lustre/experimental/element/html.caption\nsketch/lustre/experimental/element/html caption","url":"sketch/lustre/experimental/element/html.html#caption"},{"doc":"sketch/lustre/experimental/element/html","title":"caption_","content":"pub fn caption_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;caption&gt;` HTML element specifies the caption (or title) of a table, p\n roviding the table an [accessible description](https://developer.mozilla.org/docs/Glossary/Accessible_description).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/caption)\nSynonyms:\nsketch/lustre/experimental/element/html.caption_\nsketch/lustre/experimental/element/html caption_","url":"sketch/lustre/experimental/element/html.html#caption_"},{"doc":"sketch/lustre/experimental/element/html","title":"cite","content":"pub fn cite(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;cite&gt;` HTML element is used to mark up the title of a cited creative\n work. The reference may be in an abbreviated form according to\n context-appropriate conventions related to citation metadata.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/cite)\nSynonyms:\nsketch/lustre/experimental/element/html.cite\nsketch/lustre/experimental/element/html cite","url":"sketch/lustre/experimental/element/html.html#cite"},{"doc":"sketch/lustre/experimental/element/html","title":"cite_","content":"pub fn cite_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;cite&gt;` HTML element is used to mark up the title of a cited creative\n work. The reference may be in an abbreviated form according to\n context-appropriate conventions related to citation metadata.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/cite)\nSynonyms:\nsketch/lustre/experimental/element/html.cite_\nsketch/lustre/experimental/element/html cite_","url":"sketch/lustre/experimental/element/html.html#cite_"},{"doc":"sketch/lustre/experimental/element/html","title":"code","content":"pub fn code(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;code&gt;` HTML element displays its contents styled in a fashion intended\n to indicate that the text is a short fragment of computer code. By default,\n the content text is displayed using the user agent&#39;s default monospace font.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/code)\nSynonyms:\nsketch/lustre/experimental/element/html.code\nsketch/lustre/experimental/element/html code","url":"sketch/lustre/experimental/element/html.html#code"},{"doc":"sketch/lustre/experimental/element/html","title":"code_","content":"pub fn code_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;code&gt;` HTML element displays its contents styled in a fashion intended\n to indicate that the text is a short fragment of computer code. By default,\n the content text is displayed using the user agent&#39;s default monospace font.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/code)\nSynonyms:\nsketch/lustre/experimental/element/html.code_\nsketch/lustre/experimental/element/html code_","url":"sketch/lustre/experimental/element/html.html#code_"},{"doc":"sketch/lustre/experimental/element/html","title":"col","content":"pub fn col(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;col&gt;` HTML element defines one or more columns in a column group\n represented by its parent `&lt;colgroup&gt;` element. The `&lt;col&gt;` element is\n only valid as a child of a `&lt;colgroup&gt;` element that has no `span`\n attribute defined.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/col)\nSynonyms:\nsketch/lustre/experimental/element/html.col\nsketch/lustre/experimental/element/html col","url":"sketch/lustre/experimental/element/html.html#col"},{"doc":"sketch/lustre/experimental/element/html","title":"col_","content":"pub fn col_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;col&gt;` HTML element defines one or more columns in a column group\n represented by its parent `&lt;colgroup&gt;` element. The `&lt;col&gt;` element is\n only valid as a child of a `&lt;colgroup&gt;` element that has no `span`\n attribute defined.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/col)\nSynonyms:\nsketch/lustre/experimental/element/html.col_\nsketch/lustre/experimental/element/html col_","url":"sketch/lustre/experimental/element/html.html#col_"},{"doc":"sketch/lustre/experimental/element/html","title":"colgroup","content":"pub fn colgroup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;colgroup&gt;` HTML element defines a group of columns within a table.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/colgroup)\nSynonyms:\nsketch/lustre/experimental/element/html.colgroup\nsketch/lustre/experimental/element/html colgroup","url":"sketch/lustre/experimental/element/html.html#colgroup"},{"doc":"sketch/lustre/experimental/element/html","title":"colgroup_","content":"pub fn colgroup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;colgroup&gt;` HTML element defines a group of columns within a table.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/colgroup)\nSynonyms:\nsketch/lustre/experimental/element/html.colgroup_\nsketch/lustre/experimental/element/html colgroup_","url":"sketch/lustre/experimental/element/html.html#colgroup_"},{"doc":"sketch/lustre/experimental/element/html","title":"data","content":"pub fn data(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;data&gt;` HTML element links a given piece of content with a\n machine-readable translation. If the content is time- or date-related,\n the `&lt;time&gt;` element must be used.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/data)\nSynonyms:\nsketch/lustre/experimental/element/html.data\nsketch/lustre/experimental/element/html data","url":"sketch/lustre/experimental/element/html.html#data"},{"doc":"sketch/lustre/experimental/element/html","title":"data_","content":"pub fn data_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;data&gt;` HTML element links a given piece of content with a\n machine-readable translation. If the content is time- or date-related,\n the `&lt;time&gt;` element must be used.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/data)\nSynonyms:\nsketch/lustre/experimental/element/html.data_\nsketch/lustre/experimental/element/html data_","url":"sketch/lustre/experimental/element/html.html#data_"},{"doc":"sketch/lustre/experimental/element/html","title":"datalist","content":"pub fn datalist(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;datalist&gt;` HTML element contains a set of `&lt;option&gt;` elements that\n represent the permissible or recommended options available to choose from\n within other controls.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/datalist)\nSynonyms:\nsketch/lustre/experimental/element/html.datalist\nsketch/lustre/experimental/element/html datalist","url":"sketch/lustre/experimental/element/html.html#datalist"},{"doc":"sketch/lustre/experimental/element/html","title":"datalist_","content":"pub fn datalist_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;datalist&gt;` HTML element contains a set of `&lt;option&gt;` elements that\n represent the permissible or recommended options available to choose from\n within other controls.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/datalist)\nSynonyms:\nsketch/lustre/experimental/element/html.datalist_\nsketch/lustre/experimental/element/html datalist_","url":"sketch/lustre/experimental/element/html.html#datalist_"},{"doc":"sketch/lustre/experimental/element/html","title":"dd","content":"pub fn dd(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dd&gt;` HTML element provides the description, definition, or value for\n the preceding term (`&lt;dt&gt;`) in a description list (`&lt;dl&gt;`).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dd)\nSynonyms:\nsketch/lustre/experimental/element/html.dd\nsketch/lustre/experimental/element/html dd","url":"sketch/lustre/experimental/element/html.html#dd"},{"doc":"sketch/lustre/experimental/element/html","title":"dd_","content":"pub fn dd_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dd&gt;` HTML element provides the description, definition, or value for\n the preceding term (`&lt;dt&gt;`) in a description list (`&lt;dl&gt;`).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dd)\nSynonyms:\nsketch/lustre/experimental/element/html.dd_\nsketch/lustre/experimental/element/html dd_","url":"sketch/lustre/experimental/element/html.html#dd_"},{"doc":"sketch/lustre/experimental/element/html","title":"del","content":"pub fn del(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;del&gt;` HTML element represents a range of text that has been deleted\n from a document. This can be used when rendering &quot;track changes&quot; or source\n code diff information, for example. The `&lt;ins&gt;` element can be used for the\n opposite purpose: to indicate text that has been added to the document.\n\n This element is often (but need not be) rendered by applying a\n strike-through style to the text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/del)\nSynonyms:\nsketch/lustre/experimental/element/html.del\nsketch/lustre/experimental/element/html del","url":"sketch/lustre/experimental/element/html.html#del"},{"doc":"sketch/lustre/experimental/element/html","title":"del_","content":"pub fn del_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;del&gt;` HTML element represents a range of text that has been deleted\n from a document. This can be used when rendering &quot;track changes&quot; or source\n code diff information, for example. The `&lt;ins&gt;` element can be used for the\n opposite purpose: to indicate text that has been added to the document.\n\n This element is often (but need not be) rendered by applying a\n strike-through style to the text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/del)\nSynonyms:\nsketch/lustre/experimental/element/html.del_\nsketch/lustre/experimental/element/html del_","url":"sketch/lustre/experimental/element/html.html#del_"},{"doc":"sketch/lustre/experimental/element/html","title":"details","content":"pub fn details(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;details&gt;` HTML element creates a disclosure widget in which\n information is visible only when the widget is toggled into an &quot;open&quot; state.\n A summary or label must be provided using the `&lt;summary&gt;` element.\n\n A disclosure widget is typically presented onscreen using a small triangle\n that rotates (or twists) to indicate open/closed status, with a label next\n to the triangle. The contents of the `&lt;summary&gt;` element are used as the\n label for the disclosure widget. The contents of the `&lt;details&gt;` provide\n the accessible description for the `&lt;summary&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/details)\nSynonyms:\nsketch/lustre/experimental/element/html.details\nsketch/lustre/experimental/element/html details","url":"sketch/lustre/experimental/element/html.html#details"},{"doc":"sketch/lustre/experimental/element/html","title":"details_","content":"pub fn details_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;details&gt;` HTML element creates a disclosure widget in which\n information is visible only when the widget is toggled into an &quot;open&quot; state.\n A summary or label must be provided using the `&lt;summary&gt;` element.\n\n A disclosure widget is typically presented onscreen using a small triangle\n that rotates (or twists) to indicate open/closed status, with a label next\n to the triangle. The contents of the `&lt;summary&gt;` element are used as the\n label for the disclosure widget. The contents of the `&lt;details&gt;` provide\n the accessible description for the `&lt;summary&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/details)\nSynonyms:\nsketch/lustre/experimental/element/html.details_\nsketch/lustre/experimental/element/html details_","url":"sketch/lustre/experimental/element/html.html#details_"},{"doc":"sketch/lustre/experimental/element/html","title":"dfn","content":"pub fn dfn(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dfn&gt;` HTML element indicates a term to be defined. The `&lt;dfn&gt;` element\n should be used in a complete definition statement, where the full definition\n of the term can be one of the following:\n - The ancestor paragraph (a block of text, sometimes marked by a `&lt;p&gt;`\n   element)\n - The `&lt;dt&gt;`/`&lt;dd&gt;` pairing\n - The nearest section ancestor of the `&lt;dfn&gt;` element\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dfn)\nSynonyms:\nsketch/lustre/experimental/element/html.dfn\nsketch/lustre/experimental/element/html dfn","url":"sketch/lustre/experimental/element/html.html#dfn"},{"doc":"sketch/lustre/experimental/element/html","title":"dfn_","content":"pub fn dfn_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dfn&gt;` HTML element indicates a term to be defined. The `&lt;dfn&gt;` element\n should be used in a complete definition statement, where the full definition\n of the term can be one of the following:\n - The ancestor paragraph (a block of text, sometimes marked by a `&lt;p&gt;`\n   element)\n - The `&lt;dt&gt;`/`&lt;dd&gt;` pairing\n - The nearest section ancestor of the `&lt;dfn&gt;` element\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dfn)\nSynonyms:\nsketch/lustre/experimental/element/html.dfn_\nsketch/lustre/experimental/element/html dfn_","url":"sketch/lustre/experimental/element/html.html#dfn_"},{"doc":"sketch/lustre/experimental/element/html","title":"dialog","content":"pub fn dialog(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dialog&gt;` HTML element represents a modal or non-modal dialog box or\n other interactive component, such as a dismissible alert, inspector, or\n subwindow.\n\n The HTML `&lt;dialog&gt;` element is used to create both modal and non-modal\n dialog boxes. Modal dialog boxes interrupt interaction with the rest of the\n page being inert, while non-modal dialog boxes allow interaction with the\n rest of the page.\n\n JavaScript should be used to display the `&lt;dialog&gt;` element. Use the\n `.showModal()` method to display a modal dialog and the `.show()` method\n to display a non-modal dialog. The dialog box can be closed using the\n `.close()` method or using the `dialog` method when submitting a `&lt;form&gt;`\n that is nested within the `&lt;dialog&gt;` element. Modal dialogs can also be\n closed by pressing the Esc key.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dialog)\nSynonyms:\nsketch/lustre/experimental/element/html.dialog\nsketch/lustre/experimental/element/html dialog","url":"sketch/lustre/experimental/element/html.html#dialog"},{"doc":"sketch/lustre/experimental/element/html","title":"dialog_","content":"pub fn dialog_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dialog&gt;` HTML element represents a modal or non-modal dialog box or\n other interactive component, such as a dismissible alert, inspector, or\n subwindow.\n\n The HTML `&lt;dialog&gt;` element is used to create both modal and non-modal\n dialog boxes. Modal dialog boxes interrupt interaction with the rest of the\n page being inert, while non-modal dialog boxes allow interaction with the\n rest of the page.\n\n JavaScript should be used to display the `&lt;dialog&gt;` element. Use the\n `.showModal()` method to display a modal dialog and the `.show()` method\n to display a non-modal dialog. The dialog box can be closed using the\n `.close()` method or using the `dialog` method when submitting a `&lt;form&gt;`\n that is nested within the `&lt;dialog&gt;` element. Modal dialogs can also be\n closed by pressing the Esc key.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dialog)\nSynonyms:\nsketch/lustre/experimental/element/html.dialog_\nsketch/lustre/experimental/element/html dialog_","url":"sketch/lustre/experimental/element/html.html#dialog_"},{"doc":"sketch/lustre/experimental/element/html","title":"div","content":"pub fn div(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;div&gt;` HTML element is the generic container for flow content. It has\n no effect on the content or layout until styled in some way using CSS (e.g.\n styling is directly applied to it, or some kind of layout model like Flexbox\n is applied to its parent element).\n\n As a &quot;pure&quot; container, the `&lt;div&gt;` element does not inherently represent\n anything. Instead, it&#39;s used to group content so it can be easily styled\n using the `class` or `id` attributes, marking a section of a document as\n being written in a different language (using the `lang` attribute),\n and so on.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/div)\nSynonyms:\nsketch/lustre/experimental/element/html.div\nsketch/lustre/experimental/element/html div","url":"sketch/lustre/experimental/element/html.html#div"},{"doc":"sketch/lustre/experimental/element/html","title":"div_","content":"pub fn div_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;div&gt;` HTML element is the generic container for flow content. It has\n no effect on the content or layout until styled in some way using CSS (e.g.\n styling is directly applied to it, or some kind of layout model like Flexbox\n is applied to its parent element).\n\n As a &quot;pure&quot; container, the `&lt;div&gt;` element does not inherently represent\n anything. Instead, it&#39;s used to group content so it can be easily styled\n using the `class` or `id` attributes, marking a section of a document as\n being written in a different language (using the `lang` attribute),\n and so on.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/div)\nSynonyms:\nsketch/lustre/experimental/element/html.div_\nsketch/lustre/experimental/element/html div_","url":"sketch/lustre/experimental/element/html.html#div_"},{"doc":"sketch/lustre/experimental/element/html","title":"dl","content":"pub fn dl(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dl&gt;` HTML element represents a description list. The element encloses\n a list of groups of terms (specified using the `&lt;dt&gt;` element) and\n descriptions (provided by `&lt;dd&gt;` elements). Common uses for this element are\n to implement a glossary or to display metadata (a list of key-value pairs).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dl)\nSynonyms:\nsketch/lustre/experimental/element/html.dl\nsketch/lustre/experimental/element/html dl","url":"sketch/lustre/experimental/element/html.html#dl"},{"doc":"sketch/lustre/experimental/element/html","title":"dl_","content":"pub fn dl_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dl&gt;` HTML element represents a description list. The element encloses\n a list of groups of terms (specified using the `&lt;dt&gt;` element) and\n descriptions (provided by `&lt;dd&gt;` elements). Common uses for this element are\n to implement a glossary or to display metadata (a list of key-value pairs).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dl)\nSynonyms:\nsketch/lustre/experimental/element/html.dl_\nsketch/lustre/experimental/element/html dl_","url":"sketch/lustre/experimental/element/html.html#dl_"},{"doc":"sketch/lustre/experimental/element/html","title":"dt","content":"pub fn dt(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dt&gt;` HTML element specifies a term in a description or definition list,\n and as such must be used inside a `&lt;dl&gt;` element. It is usually followed by\n a `&lt;dd&gt;` element; however, multiple `&lt;dt&gt;` elements in a row indicate several\n terms that are all defined by the immediate next `&lt;dd&gt;` element.\n\n The subsequent `&lt;dd&gt;` (Description Details) element provides the definition\n or other related text associated with the term specified using `&lt;dt&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dt)\nSynonyms:\nsketch/lustre/experimental/element/html.dt\nsketch/lustre/experimental/element/html dt","url":"sketch/lustre/experimental/element/html.html#dt"},{"doc":"sketch/lustre/experimental/element/html","title":"dt_","content":"pub fn dt_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;dt&gt;` HTML element specifies a term in a description or definition list,\n and as such must be used inside a `&lt;dl&gt;` element. It is usually followed by\n a `&lt;dd&gt;` element; however, multiple `&lt;dt&gt;` elements in a row indicate several\n terms that are all defined by the immediate next `&lt;dd&gt;` element.\n\n The subsequent `&lt;dd&gt;` (Description Details) element provides the definition\n or other related text associated with the term specified using `&lt;dt&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/dt)\nSynonyms:\nsketch/lustre/experimental/element/html.dt_\nsketch/lustre/experimental/element/html dt_","url":"sketch/lustre/experimental/element/html.html#dt_"},{"doc":"sketch/lustre/experimental/element/html","title":"em","content":"pub fn em(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;em&gt;` HTML element marks text that has stress emphasis. The `&lt;em&gt;`\n element can be nested, with each level of nesting indicating a greater\n degree of emphasis.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/em)\nSynonyms:\nsketch/lustre/experimental/element/html.em\nsketch/lustre/experimental/element/html em","url":"sketch/lustre/experimental/element/html.html#em"},{"doc":"sketch/lustre/experimental/element/html","title":"em_","content":"pub fn em_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;em&gt;` HTML element marks text that has stress emphasis. The `&lt;em&gt;`\n element can be nested, with each level of nesting indicating a greater\n degree of emphasis.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/em)\nSynonyms:\nsketch/lustre/experimental/element/html.em_\nsketch/lustre/experimental/element/html em_","url":"sketch/lustre/experimental/element/html.html#em_"},{"doc":"sketch/lustre/experimental/element/html","title":"embed","content":"pub fn embed(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;embed&gt;` HTML element embeds external content at the specified point in\n the document. This content is provided by an external application or other\n source of interactive content such as a browser plug-in.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/embed)\nSynonyms:\nsketch/lustre/experimental/element/html.embed\nsketch/lustre/experimental/element/html embed","url":"sketch/lustre/experimental/element/html.html#embed"},{"doc":"sketch/lustre/experimental/element/html","title":"embed_","content":"pub fn embed_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;embed&gt;` HTML element embeds external content at the specified point in\n the document. This content is provided by an external application or other\n source of interactive content such as a browser plug-in.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/embed)\nSynonyms:\nsketch/lustre/experimental/element/html.embed_\nsketch/lustre/experimental/element/html embed_","url":"sketch/lustre/experimental/element/html.html#embed_"},{"doc":"sketch/lustre/experimental/element/html","title":"fieldset","content":"pub fn fieldset(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;fieldset&gt;` HTML element is used to group several controls as well as\n labels (`&lt;label&gt;`) within a web form.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/fieldset)\nSynonyms:\nsketch/lustre/experimental/element/html.fieldset\nsketch/lustre/experimental/element/html fieldset","url":"sketch/lustre/experimental/element/html.html#fieldset"},{"doc":"sketch/lustre/experimental/element/html","title":"fieldset_","content":"pub fn fieldset_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;fieldset&gt;` HTML element is used to group several controls as well as\n labels (`&lt;label&gt;`) within a web form.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/fieldset)\nSynonyms:\nsketch/lustre/experimental/element/html.fieldset_\nsketch/lustre/experimental/element/html fieldset_","url":"sketch/lustre/experimental/element/html.html#fieldset_"},{"doc":"sketch/lustre/experimental/element/html","title":"figcaption","content":"pub fn figcaption(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;figcaption&gt;` HTML element represents a caption or legend describing\n the rest of the contents of its parent `&lt;figure&gt;` element, providing the\n `&lt;figure&gt;` an [accessible description](https://developer.mozilla.org/docs/Glossary/Accessible_description).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/figcaption)\nSynonyms:\nsketch/lustre/experimental/element/html.figcaption\nsketch/lustre/experimental/element/html figcaption","url":"sketch/lustre/experimental/element/html.html#figcaption"},{"doc":"sketch/lustre/experimental/element/html","title":"figcaption_","content":"pub fn figcaption_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;figcaption&gt;` HTML element represents a caption or legend describing\n the rest of the contents of its parent `&lt;figure&gt;` element, providing the\n `&lt;figure&gt;` an [accessible description](https://developer.mozilla.org/docs/Glossary/Accessible_description).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/figcaption)\nSynonyms:\nsketch/lustre/experimental/element/html.figcaption_\nsketch/lustre/experimental/element/html figcaption_","url":"sketch/lustre/experimental/element/html.html#figcaption_"},{"doc":"sketch/lustre/experimental/element/html","title":"figure","content":"pub fn figure(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;figure&gt;` HTML element represents self-contained content, potentially\n with an optional caption, which is specified using the `&lt;figcaption&gt;`\n element. The figure, its caption, and its contents are referenced as a\n single unit.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/figure)\nSynonyms:\nsketch/lustre/experimental/element/html.figure\nsketch/lustre/experimental/element/html figure","url":"sketch/lustre/experimental/element/html.html#figure"},{"doc":"sketch/lustre/experimental/element/html","title":"figure_","content":"pub fn figure_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;figure&gt;` HTML element represents self-contained content, potentially\n with an optional caption, which is specified using the `&lt;figcaption&gt;`\n element. The figure, its caption, and its contents are referenced as a\n single unit.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/figure)\nSynonyms:\nsketch/lustre/experimental/element/html.figure_\nsketch/lustre/experimental/element/html figure_","url":"sketch/lustre/experimental/element/html.html#figure_"},{"doc":"sketch/lustre/experimental/element/html","title":"footer","content":"pub fn footer(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;footer&gt;` HTML element represents a footer for its nearest ancestor\n [sectioning content](https://developer.mozilla.org/docs/Web/HTML/Content_categories#sectioning_content)\n or [sectioning root](https://developer.mozilla.org/docs/Web/HTML/Element/Heading_Elements#labeling_section_content)\n element. A `&lt;footer&gt;` typically contains information about the author of\n the section, copyright data or links to related documents.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/footer)\nSynonyms:\nsketch/lustre/experimental/element/html.footer\nsketch/lustre/experimental/element/html footer","url":"sketch/lustre/experimental/element/html.html#footer"},{"doc":"sketch/lustre/experimental/element/html","title":"footer_","content":"pub fn footer_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;footer&gt;` HTML element represents a footer for its nearest ancestor\n [sectioning content](https://developer.mozilla.org/docs/Web/HTML/Content_categories#sectioning_content)\n or [sectioning root](https://developer.mozilla.org/docs/Web/HTML/Element/Heading_Elements#labeling_section_content)\n element. A `&lt;footer&gt;` typically contains information about the author of\n the section, copyright data or links to related documents.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/footer)\nSynonyms:\nsketch/lustre/experimental/element/html.footer_\nsketch/lustre/experimental/element/html footer_","url":"sketch/lustre/experimental/element/html.html#footer_"},{"doc":"sketch/lustre/experimental/element/html","title":"form","content":"pub fn form(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;form&gt;` HTML element represents a document section containing\n interactive controls for submitting information.\n\n It is possible to use the `:valid` and `:invalid` CSS pseudo-classes to\n style a `&lt;form&gt;` element based on whether the elements inside the form\n are valid.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/form)\nSynonyms:\nsketch/lustre/experimental/element/html.form\nsketch/lustre/experimental/element/html form","url":"sketch/lustre/experimental/element/html.html#form"},{"doc":"sketch/lustre/experimental/element/html","title":"form_","content":"pub fn form_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;form&gt;` HTML element represents a document section containing\n interactive controls for submitting information.\n\n It is possible to use the `:valid` and `:invalid` CSS pseudo-classes to\n style a `&lt;form&gt;` element based on whether the elements inside the form\n are valid.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/form)\nSynonyms:\nsketch/lustre/experimental/element/html.form_\nsketch/lustre/experimental/element/html form_","url":"sketch/lustre/experimental/element/html.html#form_"},{"doc":"sketch/lustre/experimental/element/html","title":"h1","content":"pub fn h1(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h1)\nSynonyms:\nsketch/lustre/experimental/element/html.h1\nsketch/lustre/experimental/element/html h1","url":"sketch/lustre/experimental/element/html.html#h1"},{"doc":"sketch/lustre/experimental/element/html","title":"h1_","content":"pub fn h1_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h1)\nSynonyms:\nsketch/lustre/experimental/element/html.h1_\nsketch/lustre/experimental/element/html h1_","url":"sketch/lustre/experimental/element/html.html#h1_"},{"doc":"sketch/lustre/experimental/element/html","title":"h2","content":"pub fn h2(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h2)\nSynonyms:\nsketch/lustre/experimental/element/html.h2\nsketch/lustre/experimental/element/html h2","url":"sketch/lustre/experimental/element/html.html#h2"},{"doc":"sketch/lustre/experimental/element/html","title":"h2_","content":"pub fn h2_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h2)\nSynonyms:\nsketch/lustre/experimental/element/html.h2_\nsketch/lustre/experimental/element/html h2_","url":"sketch/lustre/experimental/element/html.html#h2_"},{"doc":"sketch/lustre/experimental/element/html","title":"h3","content":"pub fn h3(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h3)\nSynonyms:\nsketch/lustre/experimental/element/html.h3\nsketch/lustre/experimental/element/html h3","url":"sketch/lustre/experimental/element/html.html#h3"},{"doc":"sketch/lustre/experimental/element/html","title":"h3_","content":"pub fn h3_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h3)\nSynonyms:\nsketch/lustre/experimental/element/html.h3_\nsketch/lustre/experimental/element/html h3_","url":"sketch/lustre/experimental/element/html.html#h3_"},{"doc":"sketch/lustre/experimental/element/html","title":"h4","content":"pub fn h4(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h4)\nSynonyms:\nsketch/lustre/experimental/element/html.h4\nsketch/lustre/experimental/element/html h4","url":"sketch/lustre/experimental/element/html.html#h4"},{"doc":"sketch/lustre/experimental/element/html","title":"h4_","content":"pub fn h4_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h4)\nSynonyms:\nsketch/lustre/experimental/element/html.h4_\nsketch/lustre/experimental/element/html h4_","url":"sketch/lustre/experimental/element/html.html#h4_"},{"doc":"sketch/lustre/experimental/element/html","title":"h5","content":"pub fn h5(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h5)\nSynonyms:\nsketch/lustre/experimental/element/html.h5\nsketch/lustre/experimental/element/html h5","url":"sketch/lustre/experimental/element/html.html#h5"},{"doc":"sketch/lustre/experimental/element/html","title":"h5_","content":"pub fn h5_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h5)\nSynonyms:\nsketch/lustre/experimental/element/html.h5_\nsketch/lustre/experimental/element/html h5_","url":"sketch/lustre/experimental/element/html.html#h5_"},{"doc":"sketch/lustre/experimental/element/html","title":"h6","content":"pub fn h6(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h6)\nSynonyms:\nsketch/lustre/experimental/element/html.h6\nsketch/lustre/experimental/element/html h6","url":"sketch/lustre/experimental/element/html.html#h6"},{"doc":"sketch/lustre/experimental/element/html","title":"h6_","content":"pub fn h6_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;h1&gt;` to `&lt;h6&gt;` HTML elements represent six levels of section headings.\n `&lt;h1&gt;` is the highest section level and `&lt;h6&gt;` is the lowest. By default,\n all heading elements create a block-level box in the layout, starting on a\n new line and taking up the full width available in their containing block.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/h6)\nSynonyms:\nsketch/lustre/experimental/element/html.h6_\nsketch/lustre/experimental/element/html h6_","url":"sketch/lustre/experimental/element/html.html#h6_"},{"doc":"sketch/lustre/experimental/element/html","title":"head","content":"pub fn head(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;head&gt;` HTML element contains machine-readable information (metadata)\n about the document, like its title, scripts, and style sheets. There can be\n only one `&lt;head&gt;` element in an HTML document.\n\n &gt; `&lt;head&gt;` primarily holds information for machine processing, not\n &gt; human-readability. For human-visible information, like top-level headings\n &gt; and listed authors, see the `&lt;header&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/head)\nSynonyms:\nsketch/lustre/experimental/element/html.head\nsketch/lustre/experimental/element/html head","url":"sketch/lustre/experimental/element/html.html#head"},{"doc":"sketch/lustre/experimental/element/html","title":"header","content":"pub fn header(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;header&gt;` HTML element represents introductory content, typically a\n group of introductory or navigational aids. It may contain some heading\n elements but also a logo, a search form, an author name, and other elements.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/header)\nSynonyms:\nsketch/lustre/experimental/element/html.header\nsketch/lustre/experimental/element/html header","url":"sketch/lustre/experimental/element/html.html#header"},{"doc":"sketch/lustre/experimental/element/html","title":"header_","content":"pub fn header_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;header&gt;` HTML element represents introductory content, typically a\n group of introductory or navigational aids. It may contain some heading\n elements but also a logo, a search form, an author name, and other elements.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/header)\nSynonyms:\nsketch/lustre/experimental/element/html.header_\nsketch/lustre/experimental/element/html header_","url":"sketch/lustre/experimental/element/html.html#header_"},{"doc":"sketch/lustre/experimental/element/html","title":"hgroup","content":"pub fn hgroup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;hgroup&gt;` HTML element represents a heading and related content. It\n groups a single `&lt;h1&gt;`–`&lt;h6&gt;` element with one or more `&lt;p&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/hgroup)\nSynonyms:\nsketch/lustre/experimental/element/html.hgroup\nsketch/lustre/experimental/element/html hgroup","url":"sketch/lustre/experimental/element/html.html#hgroup"},{"doc":"sketch/lustre/experimental/element/html","title":"hgroup_","content":"pub fn hgroup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;hgroup&gt;` HTML element represents a heading and related content. It\n groups a single `&lt;h1&gt;`–`&lt;h6&gt;` element with one or more `&lt;p&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/hgroup)\nSynonyms:\nsketch/lustre/experimental/element/html.hgroup_\nsketch/lustre/experimental/element/html hgroup_","url":"sketch/lustre/experimental/element/html.html#hgroup_"},{"doc":"sketch/lustre/experimental/element/html","title":"hr","content":"pub fn hr(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;hr&gt;` HTML element represents a thematic break between paragraph-level\n elements: for example, a change of scene in a story, or a shift of topic\n within a section.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/hr)\nSynonyms:\nsketch/lustre/experimental/element/html.hr\nsketch/lustre/experimental/element/html hr","url":"sketch/lustre/experimental/element/html.html#hr"},{"doc":"sketch/lustre/experimental/element/html","title":"hr_","content":"pub fn hr_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;hr&gt;` HTML element represents a thematic break between paragraph-level\n elements: for example, a change of scene in a story, or a shift of topic\n within a section.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/hr)\nSynonyms:\nsketch/lustre/experimental/element/html.hr_\nsketch/lustre/experimental/element/html hr_","url":"sketch/lustre/experimental/element/html.html#hr_"},{"doc":"sketch/lustre/experimental/element/html","title":"html","content":"pub fn html(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;html&gt;` HTML element represents the root (top-level element) of an\n HTML document, so it is also referred to as the root element. All other\n elements must be descendants of this element. There can be only one `&lt;html&gt;`\n element in a document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/html)\nSynonyms:\nsketch/lustre/experimental/element/html.html\nsketch/lustre/experimental/element/html html","url":"sketch/lustre/experimental/element/html.html#html"},{"doc":"sketch/lustre/experimental/element/html","title":"i","content":"pub fn i(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;i&gt;` HTML element represents a range of text that is set off from the\n normal text for some reason, such as idiomatic text, technical terms,\n taxonomical designations, among others. Historically, these have been\n presented using italicized type, which is the original source of the `&lt;i&gt;`\n naming of this element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/i)\nSynonyms:\nsketch/lustre/experimental/element/html.i\nsketch/lustre/experimental/element/html i","url":"sketch/lustre/experimental/element/html.html#i"},{"doc":"sketch/lustre/experimental/element/html","title":"i_","content":"pub fn i_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;i&gt;` HTML element represents a range of text that is set off from the\n normal text for some reason, such as idiomatic text, technical terms,\n taxonomical designations, among others. Historically, these have been\n presented using italicized type, which is the original source of the `&lt;i&gt;`\n naming of this element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/i)\nSynonyms:\nsketch/lustre/experimental/element/html.i_\nsketch/lustre/experimental/element/html i_","url":"sketch/lustre/experimental/element/html.html#i_"},{"doc":"sketch/lustre/experimental/element/html","title":"iframe","content":"pub fn iframe(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;iframe&gt;` HTML element represents a nested browsing context, embedding\n another HTML page into the current one.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/iframe)\nSynonyms:\nsketch/lustre/experimental/element/html.iframe\nsketch/lustre/experimental/element/html iframe","url":"sketch/lustre/experimental/element/html.html#iframe"},{"doc":"sketch/lustre/experimental/element/html","title":"iframe_","content":"pub fn iframe_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;iframe&gt;` HTML element represents a nested browsing context, embedding\n another HTML page into the current one.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/iframe)\nSynonyms:\nsketch/lustre/experimental/element/html.iframe_\nsketch/lustre/experimental/element/html iframe_","url":"sketch/lustre/experimental/element/html.html#iframe_"},{"doc":"sketch/lustre/experimental/element/html","title":"img","content":"pub fn img(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;img&gt;` HTML element embeds an image into the document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/img)\nSynonyms:\nsketch/lustre/experimental/element/html.img\nsketch/lustre/experimental/element/html img","url":"sketch/lustre/experimental/element/html.html#img"},{"doc":"sketch/lustre/experimental/element/html","title":"img_","content":"pub fn img_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;img&gt;` HTML element embeds an image into the document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/img)\nSynonyms:\nsketch/lustre/experimental/element/html.img_\nsketch/lustre/experimental/element/html img_","url":"sketch/lustre/experimental/element/html.html#img_"},{"doc":"sketch/lustre/experimental/element/html","title":"input","content":"pub fn input(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;input&gt;` HTML element is used to create interactive controls for\n web-based forms in order to accept data from the user; a wide variety of\n types of input data and control widgets are available, depending on the\n device and user agent. The `&lt;input&gt;` element is one of the most powerful and\n complex in all of HTML due to the sheer number of combinations of input\n types and attributes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/input)\nSynonyms:\nsketch/lustre/experimental/element/html.input\nsketch/lustre/experimental/element/html input","url":"sketch/lustre/experimental/element/html.html#input"},{"doc":"sketch/lustre/experimental/element/html","title":"input_","content":"pub fn input_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;input&gt;` HTML element is used to create interactive controls for\n web-based forms in order to accept data from the user; a wide variety of\n types of input data and control widgets are available, depending on the\n device and user agent. The `&lt;input&gt;` element is one of the most powerful and\n complex in all of HTML due to the sheer number of combinations of input\n types and attributes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/input)\nSynonyms:\nsketch/lustre/experimental/element/html.input_\nsketch/lustre/experimental/element/html input_","url":"sketch/lustre/experimental/element/html.html#input_"},{"doc":"sketch/lustre/experimental/element/html","title":"ins","content":"pub fn ins(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ins&gt;` HTML element represents a range of text that has been added to\n a document. You can use the `&lt;del&gt;` element to similarly represent a range\n of text that has been deleted from the document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ins)\nSynonyms:\nsketch/lustre/experimental/element/html.ins\nsketch/lustre/experimental/element/html ins","url":"sketch/lustre/experimental/element/html.html#ins"},{"doc":"sketch/lustre/experimental/element/html","title":"ins_","content":"pub fn ins_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ins&gt;` HTML element represents a range of text that has been added to\n a document. You can use the `&lt;del&gt;` element to similarly represent a range\n of text that has been deleted from the document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ins)\nSynonyms:\nsketch/lustre/experimental/element/html.ins_\nsketch/lustre/experimental/element/html ins_","url":"sketch/lustre/experimental/element/html.html#ins_"},{"doc":"sketch/lustre/experimental/element/html","title":"kbd","content":"pub fn kbd(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;kbd&gt;` HTML element represents a span of inline text denoting textual\n user input from a keyboard, voice input, or any other text entry device. By\n convention, the user agent defaults to rendering the contents of a `&lt;kbd&gt;`\n element using its default monospace font, although this is not mandated by\n the HTML standard.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/kbd)\nSynonyms:\nsketch/lustre/experimental/element/html.kbd\nsketch/lustre/experimental/element/html kbd","url":"sketch/lustre/experimental/element/html.html#kbd"},{"doc":"sketch/lustre/experimental/element/html","title":"kbd_","content":"pub fn kbd_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;kbd&gt;` HTML element represents a span of inline text denoting textual\n user input from a keyboard, voice input, or any other text entry device. By\n convention, the user agent defaults to rendering the contents of a `&lt;kbd&gt;`\n element using its default monospace font, although this is not mandated by\n the HTML standard.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/kbd)\nSynonyms:\nsketch/lustre/experimental/element/html.kbd_\nsketch/lustre/experimental/element/html kbd_","url":"sketch/lustre/experimental/element/html.html#kbd_"},{"doc":"sketch/lustre/experimental/element/html","title":"label","content":"pub fn label(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;label&gt;` HTML element represents a caption for an item in a user\n interface.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/label)\nSynonyms:\nsketch/lustre/experimental/element/html.label\nsketch/lustre/experimental/element/html label","url":"sketch/lustre/experimental/element/html.html#label"},{"doc":"sketch/lustre/experimental/element/html","title":"label_","content":"pub fn label_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;label&gt;` HTML element represents a caption for an item in a user\n interface.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/label)\nSynonyms:\nsketch/lustre/experimental/element/html.label_\nsketch/lustre/experimental/element/html label_","url":"sketch/lustre/experimental/element/html.html#label_"},{"doc":"sketch/lustre/experimental/element/html","title":"legend","content":"pub fn legend(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;legend&gt;` HTML element represents a caption for the content of\n its parent `&lt;fieldset&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/legend)\nSynonyms:\nsketch/lustre/experimental/element/html.legend\nsketch/lustre/experimental/element/html legend","url":"sketch/lustre/experimental/element/html.html#legend"},{"doc":"sketch/lustre/experimental/element/html","title":"legend_","content":"pub fn legend_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;legend&gt;` HTML element represents a caption for the content of\n its parent `&lt;fieldset&gt;`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/legend)\nSynonyms:\nsketch/lustre/experimental/element/html.legend_\nsketch/lustre/experimental/element/html legend_","url":"sketch/lustre/experimental/element/html.html#legend_"},{"doc":"sketch/lustre/experimental/element/html","title":"li","content":"pub fn li(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;li&gt;` HTML element is used to represent an item in a list. It must be\n contained in a parent element: an ordered list (`&lt;ol&gt;`), an unordered list\n (`&lt;ul&gt;`), or a menu (`&lt;menu&gt;`). In menus and unordered lists, list items are\n usually displayed using bullet points. In ordered lists, they are usually\n displayed with an ascending counter on the left, such as a number or letter.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/li)\nSynonyms:\nsketch/lustre/experimental/element/html.li\nsketch/lustre/experimental/element/html li","url":"sketch/lustre/experimental/element/html.html#li"},{"doc":"sketch/lustre/experimental/element/html","title":"li_","content":"pub fn li_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;li&gt;` HTML element is used to represent an item in a list. It must be\n contained in a parent element: an ordered list (`&lt;ol&gt;`), an unordered list\n (`&lt;ul&gt;`), or a menu (`&lt;menu&gt;`). In menus and unordered lists, list items are\n usually displayed using bullet points. In ordered lists, they are usually\n displayed with an ascending counter on the left, such as a number or letter.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/li)\nSynonyms:\nsketch/lustre/experimental/element/html.li_\nsketch/lustre/experimental/element/html li_","url":"sketch/lustre/experimental/element/html.html#li_"},{"doc":"sketch/lustre/experimental/element/html","title":"link","content":"pub fn link(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;link&gt;` HTML element specifies relationships between the current\n document and an external resource. This element is most commonly used to\n link to stylesheets, but is also used to establish site icons (both &quot;favicon&quot;\n style icons and icons for the home screen and apps on mobile devices) among\n other things.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/link)\nSynonyms:\nsketch/lustre/experimental/element/html.link\nsketch/lustre/experimental/element/html link","url":"sketch/lustre/experimental/element/html.html#link"},{"doc":"sketch/lustre/experimental/element/html","title":"main","content":"pub fn main(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;main&gt;` HTML element represents the dominant content of the `&lt;body&gt;` of\n a document. The main content area consists of content that is directly\n related to or expands upon the central topic of a document, or the central\n functionality of an application.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/main)\nSynonyms:\nsketch/lustre/experimental/element/html.main\nsketch/lustre/experimental/element/html main","url":"sketch/lustre/experimental/element/html.html#main"},{"doc":"sketch/lustre/experimental/element/html","title":"main_","content":"pub fn main_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;main&gt;` HTML element represents the dominant content of the `&lt;body&gt;` of\n a document. The main content area consists of content that is directly\n related to or expands upon the central topic of a document, or the central\n functionality of an application.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/main)\nSynonyms:\nsketch/lustre/experimental/element/html.main_\nsketch/lustre/experimental/element/html main_","url":"sketch/lustre/experimental/element/html.html#main_"},{"doc":"sketch/lustre/experimental/element/html","title":"map","content":"pub fn map(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;map&gt;` HTML element is used with `&lt;area&gt;` elements to define an\n image map (a clickable link area).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/map)\nSynonyms:\nsketch/lustre/experimental/element/html.map\nsketch/lustre/experimental/element/html map","url":"sketch/lustre/experimental/element/html.html#map"},{"doc":"sketch/lustre/experimental/element/html","title":"map_","content":"pub fn map_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;map&gt;` HTML element is used with `&lt;area&gt;` elements to define an\n image map (a clickable link area).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/map)\nSynonyms:\nsketch/lustre/experimental/element/html.map_\nsketch/lustre/experimental/element/html map_","url":"sketch/lustre/experimental/element/html.html#map_"},{"doc":"sketch/lustre/experimental/element/html","title":"mark","content":"pub fn mark(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;mark&gt;` HTML element represents text which is marked or highlighted for\n reference or notation purposes due to the marked passage&#39;s relevance in the\n enclosing context.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/mark)\nSynonyms:\nsketch/lustre/experimental/element/html.mark\nsketch/lustre/experimental/element/html mark","url":"sketch/lustre/experimental/element/html.html#mark"},{"doc":"sketch/lustre/experimental/element/html","title":"mark_","content":"pub fn mark_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;mark&gt;` HTML element represents text which is marked or highlighted for\n reference or notation purposes due to the marked passage&#39;s relevance in the\n enclosing context.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/mark)\nSynonyms:\nsketch/lustre/experimental/element/html.mark_\nsketch/lustre/experimental/element/html mark_","url":"sketch/lustre/experimental/element/html.html#mark_"},{"doc":"sketch/lustre/experimental/element/html","title":"math","content":"pub fn math(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;math&gt;` MathML element is the top-level MathML element, used to write\n a single mathematical formula. It can be placed in HTML content where flow\n content is permitted.\n\n &gt; See the [Authoring MathML page](https://developer.mozilla.org/docs/Web/MathML/Authoring#using_mathml)\n &gt; for tips to properly integrate MathML formulas in your web pages and the\n &gt; [Examples](https://developer.mozilla.org/docs/Web/MathML/Examples)\n &gt; page for more demos.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/MathML/Element/math)\nSynonyms:\nsketch/lustre/experimental/element/html.math\nsketch/lustre/experimental/element/html math","url":"sketch/lustre/experimental/element/html.html#math"},{"doc":"sketch/lustre/experimental/element/html","title":"math_","content":"pub fn math_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;math&gt;` MathML element is the top-level MathML element, used to write\n a single mathematical formula. It can be placed in HTML content where flow\n content is permitted.\n\n &gt; See the [Authoring MathML page](https://developer.mozilla.org/docs/Web/MathML/Authoring#using_mathml)\n &gt; for tips to properly integrate MathML formulas in your web pages and the\n &gt; [Examples](https://developer.mozilla.org/docs/Web/MathML/Examples)\n &gt; page for more demos.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/MathML/Element/math)\nSynonyms:\nsketch/lustre/experimental/element/html.math_\nsketch/lustre/experimental/element/html math_","url":"sketch/lustre/experimental/element/html.html#math_"},{"doc":"sketch/lustre/experimental/element/html","title":"menu","content":"pub fn menu(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;menu&gt;` HTML element is described in the HTML specification as a\n semantic alternative to `&lt;ul&gt;`, but treated by browsers (and exposed through\n the accessibility tree) as no different than `&lt;ul&gt;`. It represents an\n unordered list of items (which are represented by `&lt;li&gt;` elements).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/menu)\nSynonyms:\nsketch/lustre/experimental/element/html.menu\nsketch/lustre/experimental/element/html menu","url":"sketch/lustre/experimental/element/html.html#menu"},{"doc":"sketch/lustre/experimental/element/html","title":"menu_","content":"pub fn menu_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;menu&gt;` HTML element is described in the HTML specification as a\n semantic alternative to `&lt;ul&gt;`, but treated by browsers (and exposed through\n the accessibility tree) as no different than `&lt;ul&gt;`. It represents an\n unordered list of items (which are represented by `&lt;li&gt;` elements).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/menu)\nSynonyms:\nsketch/lustre/experimental/element/html.menu_\nsketch/lustre/experimental/element/html menu_","url":"sketch/lustre/experimental/element/html.html#menu_"},{"doc":"sketch/lustre/experimental/element/html","title":"meta","content":"pub fn meta(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;meta&gt;` HTML element represents metadata that cannot be represented\n by other HTML meta-related elements, like `&lt;base&gt;`, `&lt;link&gt;`, `&lt;script&gt;`,\n `&lt;style&gt;` or `&lt;title&gt;`.\n\n The type of metadata provided by the `&lt;meta&gt;` element can be one of the\n following:\n - If the `name` attribute is set, the `&lt;meta&gt;` element provides\n   document-level metadata, applying to the whole page.\n - If the `http-equiv` attribute is set, the `&lt;meta&gt;` element is a pragma\n   directive, providing information equivalent to what can be given by a\n   similarly-named HTTP header.\n - If the `charset` attribute is set, the `&lt;meta&gt;` element is a charset\n   declaration, giving the character encoding in which the document is encoded.\n - If the `itemprop` attribute is set, the `&lt;meta&gt;` element provides\n   user-defined metadata.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/meta)\nSynonyms:\nsketch/lustre/experimental/element/html.meta\nsketch/lustre/experimental/element/html meta","url":"sketch/lustre/experimental/element/html.html#meta"},{"doc":"sketch/lustre/experimental/element/html","title":"meter","content":"pub fn meter(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;meter&gt;` HTML element represents either a scalar value within a\n known range or a fractional value.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/meter)\nSynonyms:\nsketch/lustre/experimental/element/html.meter\nsketch/lustre/experimental/element/html meter","url":"sketch/lustre/experimental/element/html.html#meter"},{"doc":"sketch/lustre/experimental/element/html","title":"meter_","content":"pub fn meter_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;meter&gt;` HTML element represents either a scalar value within a\n known range or a fractional value.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/meter)\nSynonyms:\nsketch/lustre/experimental/element/html.meter_\nsketch/lustre/experimental/element/html meter_","url":"sketch/lustre/experimental/element/html.html#meter_"},{"doc":"sketch/lustre/experimental/element/html","title":"nav","content":"pub fn nav(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;nav&gt;` HTML element represents a section of a page whose purpose is to\n provide navigation links, either within the current document or to other\n documents. Common examples of navigation sections are menus, tables of\n contents, and indexes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/nav)\nSynonyms:\nsketch/lustre/experimental/element/html.nav\nsketch/lustre/experimental/element/html nav","url":"sketch/lustre/experimental/element/html.html#nav"},{"doc":"sketch/lustre/experimental/element/html","title":"nav_","content":"pub fn nav_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;nav&gt;` HTML element represents a section of a page whose purpose is to\n provide navigation links, either within the current document or to other\n documents. Common examples of navigation sections are menus, tables of\n contents, and indexes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/nav)\nSynonyms:\nsketch/lustre/experimental/element/html.nav_\nsketch/lustre/experimental/element/html nav_","url":"sketch/lustre/experimental/element/html.html#nav_"},{"doc":"sketch/lustre/experimental/element/html","title":"noscript","content":"pub fn noscript(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;noscript&gt;` HTML element defines a section of HTML to be inserted if a\n script type on the page is unsupported or if scripting is currently turned\n off in the browser.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/noscript)\nSynonyms:\nsketch/lustre/experimental/element/html.noscript\nsketch/lustre/experimental/element/html noscript","url":"sketch/lustre/experimental/element/html.html#noscript"},{"doc":"sketch/lustre/experimental/element/html","title":"noscript_","content":"pub fn noscript_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;noscript&gt;` HTML element defines a section of HTML to be inserted if a\n script type on the page is unsupported or if scripting is currently turned\n off in the browser.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/noscript)\nSynonyms:\nsketch/lustre/experimental/element/html.noscript_\nsketch/lustre/experimental/element/html noscript_","url":"sketch/lustre/experimental/element/html.html#noscript_"},{"doc":"sketch/lustre/experimental/element/html","title":"object","content":"pub fn object(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;object&gt;` HTML element represents an external resource, which can be\n treated as an image, a nested browsing context, or a resource to be handled\n by a plugin.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/object)\nSynonyms:\nsketch/lustre/experimental/element/html.object\nsketch/lustre/experimental/element/html object","url":"sketch/lustre/experimental/element/html.html#object"},{"doc":"sketch/lustre/experimental/element/html","title":"object_","content":"pub fn object_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;object&gt;` HTML element represents an external resource, which can be\n treated as an image, a nested browsing context, or a resource to be handled\n by a plugin.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/object)\nSynonyms:\nsketch/lustre/experimental/element/html.object_\nsketch/lustre/experimental/element/html object_","url":"sketch/lustre/experimental/element/html.html#object_"},{"doc":"sketch/lustre/experimental/element/html","title":"ol","content":"pub fn ol(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ol&gt;` HTML element represents an ordered list of items — typically\n rendered as a numbered list.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ol)\nSynonyms:\nsketch/lustre/experimental/element/html.ol\nsketch/lustre/experimental/element/html ol","url":"sketch/lustre/experimental/element/html.html#ol"},{"doc":"sketch/lustre/experimental/element/html","title":"ol_","content":"pub fn ol_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ol&gt;` HTML element represents an ordered list of items — typically\n rendered as a numbered list.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ol)\nSynonyms:\nsketch/lustre/experimental/element/html.ol_\nsketch/lustre/experimental/element/html ol_","url":"sketch/lustre/experimental/element/html.html#ol_"},{"doc":"sketch/lustre/experimental/element/html","title":"optgroup","content":"pub fn optgroup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;optgroup&gt;` HTML element creates a grouping of options within a\n `&lt;select&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/optgroup)\nSynonyms:\nsketch/lustre/experimental/element/html.optgroup\nsketch/lustre/experimental/element/html optgroup","url":"sketch/lustre/experimental/element/html.html#optgroup"},{"doc":"sketch/lustre/experimental/element/html","title":"optgroup_","content":"pub fn optgroup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;optgroup&gt;` HTML element creates a grouping of options within a\n `&lt;select&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/optgroup)\nSynonyms:\nsketch/lustre/experimental/element/html.optgroup_\nsketch/lustre/experimental/element/html optgroup_","url":"sketch/lustre/experimental/element/html.html#optgroup_"},{"doc":"sketch/lustre/experimental/element/html","title":"option","content":"pub fn option(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;option&gt;` HTML element is used to define an item contained in a\n `&lt;select&gt;`, an `&lt;optgroup&gt;`, or a `&lt;datalist&gt;` element. As such, `&lt;option&gt;`\n can represent menu items in popups and other lists of items in an HTML\n document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/option)\nSynonyms:\nsketch/lustre/experimental/element/html.option\nsketch/lustre/experimental/element/html option","url":"sketch/lustre/experimental/element/html.html#option"},{"doc":"sketch/lustre/experimental/element/html","title":"option_","content":"pub fn option_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;option&gt;` HTML element is used to define an item contained in a\n `&lt;select&gt;`, an `&lt;optgroup&gt;`, or a `&lt;datalist&gt;` element. As such, `&lt;option&gt;`\n can represent menu items in popups and other lists of items in an HTML\n document.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/option)\nSynonyms:\nsketch/lustre/experimental/element/html.option_\nsketch/lustre/experimental/element/html option_","url":"sketch/lustre/experimental/element/html.html#option_"},{"doc":"sketch/lustre/experimental/element/html","title":"output","content":"pub fn output(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;output&gt;` HTML element is a container element into which a site or\n app can inject the results of a calculation or the outcome of a user action.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/output)\nSynonyms:\nsketch/lustre/experimental/element/html.output\nsketch/lustre/experimental/element/html output","url":"sketch/lustre/experimental/element/html.html#output"},{"doc":"sketch/lustre/experimental/element/html","title":"output_","content":"pub fn output_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;output&gt;` HTML element is a container element into which a site or\n app can inject the results of a calculation or the outcome of a user action.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/output)\nSynonyms:\nsketch/lustre/experimental/element/html.output_\nsketch/lustre/experimental/element/html output_","url":"sketch/lustre/experimental/element/html.html#output_"},{"doc":"sketch/lustre/experimental/element/html","title":"p","content":"pub fn p(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;p&gt;` HTML element represents a paragraph. Paragraphs are usually\n represented in visual media as blocks of text separated from adjacent\n blocks by blank lines and/or first-line indentation, but HTML paragraphs\n can be any structural grouping of related content, such as images or form\n fields.\n\n Paragraphs are block-level elements, and notably will automatically close\n if another block-level element is parsed before the closing `&lt;/p&gt;` tag.\n See &quot;Tag omission&quot; below.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/p)\nSynonyms:\nsketch/lustre/experimental/element/html.p\nsketch/lustre/experimental/element/html p","url":"sketch/lustre/experimental/element/html.html#p"},{"doc":"sketch/lustre/experimental/element/html","title":"p_","content":"pub fn p_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;p&gt;` HTML element represents a paragraph. Paragraphs are usually\n represented in visual media as blocks of text separated from adjacent\n blocks by blank lines and/or first-line indentation, but HTML paragraphs\n can be any structural grouping of related content, such as images or form\n fields.\n\n Paragraphs are block-level elements, and notably will automatically close\n if another block-level element is parsed before the closing `&lt;/p&gt;` tag.\n See &quot;Tag omission&quot; below.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/p)\nSynonyms:\nsketch/lustre/experimental/element/html.p_\nsketch/lustre/experimental/element/html p_","url":"sketch/lustre/experimental/element/html.html#p_"},{"doc":"sketch/lustre/experimental/element/html","title":"picture","content":"pub fn picture(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;picture&gt;` HTML element contains zero or more `&lt;source&gt;` elements and\n one `&lt;img&gt;` element to offer alternative versions of an image for different\n display/device scenarios.\n\n The browser will consider each child `&lt;source&gt;` element and choose the best\n match among them. If no matches are found—or the browser doesn&#39;t support\n the `&lt;picture&gt;` element—the URL of the `&lt;img&gt;` element&#39;s `src` attribute is\n selected. The selected image is then presented in the space occupied by\n the `&lt;img&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/picture)\nSynonyms:\nsketch/lustre/experimental/element/html.picture\nsketch/lustre/experimental/element/html picture","url":"sketch/lustre/experimental/element/html.html#picture"},{"doc":"sketch/lustre/experimental/element/html","title":"picture_","content":"pub fn picture_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;picture&gt;` HTML element contains zero or more `&lt;source&gt;` elements and\n one `&lt;img&gt;` element to offer alternative versions of an image for different\n display/device scenarios.\n\n The browser will consider each child `&lt;source&gt;` element and choose the best\n match among them. If no matches are found—or the browser doesn&#39;t support\n the `&lt;picture&gt;` element—the URL of the `&lt;img&gt;` element&#39;s `src` attribute is\n selected. The selected image is then presented in the space occupied by\n the `&lt;img&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/picture)\nSynonyms:\nsketch/lustre/experimental/element/html.picture_\nsketch/lustre/experimental/element/html picture_","url":"sketch/lustre/experimental/element/html.html#picture_"},{"doc":"sketch/lustre/experimental/element/html","title":"portal","content":"pub fn portal(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;portal&gt;` HTML element enables the embedding of another HTML page into\n the current one for the purposes of allowing smoother navigation into new pages.\n\n A `&lt;portal&gt;` is similar to an `&lt;iframe&gt;`. An `&lt;iframe&gt;` allows a separate\n browsing context to be embedded. However, the embedded content of a\n `&lt;portal&gt;` is more limited than that of an `&lt;iframe&gt;`. It cannot be\n interacted with, and therefore is not suitable for embedding widgets into a\n document. Instead, the &lt;portal&gt; acts as a preview of the content of another\n page. It can be navigated into therefore allowing for seamless transition\n to the embedded content.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/portal)\nSynonyms:\nsketch/lustre/experimental/element/html.portal\nsketch/lustre/experimental/element/html portal","url":"sketch/lustre/experimental/element/html.html#portal"},{"doc":"sketch/lustre/experimental/element/html","title":"portal_","content":"pub fn portal_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;portal&gt;` HTML element enables the embedding of another HTML page into\n the current one for the purposes of allowing smoother navigation into new pages.\n\n A `&lt;portal&gt;` is similar to an `&lt;iframe&gt;`. An `&lt;iframe&gt;` allows a separate\n browsing context to be embedded. However, the embedded content of a\n `&lt;portal&gt;` is more limited than that of an `&lt;iframe&gt;`. It cannot be\n interacted with, and therefore is not suitable for embedding widgets into a\n document. Instead, the &lt;portal&gt; acts as a preview of the content of another\n page. It can be navigated into therefore allowing for seamless transition\n to the embedded content.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/portal)\nSynonyms:\nsketch/lustre/experimental/element/html.portal_\nsketch/lustre/experimental/element/html portal_","url":"sketch/lustre/experimental/element/html.html#portal_"},{"doc":"sketch/lustre/experimental/element/html","title":"pre","content":"pub fn pre(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;pre&gt;` HTML element represents preformatted text which is to be\n presented exactly as written in the HTML file. The text is typically\n rendered using a non-proportional, or monospaced, font. Whitespace inside\n this element is displayed as written.\n\n By default, `&lt;pre&gt;` is a block-level element, i.e. its default `display`\n value is `block`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/pre)\nSynonyms:\nsketch/lustre/experimental/element/html.pre\nsketch/lustre/experimental/element/html pre","url":"sketch/lustre/experimental/element/html.html#pre"},{"doc":"sketch/lustre/experimental/element/html","title":"pre_","content":"pub fn pre_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;pre&gt;` HTML element represents preformatted text which is to be\n presented exactly as written in the HTML file. The text is typically\n rendered using a non-proportional, or monospaced, font. Whitespace inside\n this element is displayed as written.\n\n By default, `&lt;pre&gt;` is a block-level element, i.e. its default `display`\n value is `block`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/pre)\nSynonyms:\nsketch/lustre/experimental/element/html.pre_\nsketch/lustre/experimental/element/html pre_","url":"sketch/lustre/experimental/element/html.html#pre_"},{"doc":"sketch/lustre/experimental/element/html","title":"progress","content":"pub fn progress(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;progress&gt;` HTML element displays an indicator showing the completion\n progress of a task, typically displayed as a progress bar.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/progress)\nSynonyms:\nsketch/lustre/experimental/element/html.progress\nsketch/lustre/experimental/element/html progress","url":"sketch/lustre/experimental/element/html.html#progress"},{"doc":"sketch/lustre/experimental/element/html","title":"progress_","content":"pub fn progress_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;progress&gt;` HTML element displays an indicator showing the completion\n progress of a task, typically displayed as a progress bar.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/progress)\nSynonyms:\nsketch/lustre/experimental/element/html.progress_\nsketch/lustre/experimental/element/html progress_","url":"sketch/lustre/experimental/element/html.html#progress_"},{"doc":"sketch/lustre/experimental/element/html","title":"q","content":"pub fn q(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;q&gt;` HTML element indicates that the enclosed text is a short inline\n quotation. Most modern browsers implement this by surrounding the text in\n quotation marks. This element is intended for short quotations that don&#39;t\n require paragraph breaks; for long quotations use the `&lt;blockquote&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/q)\nSynonyms:\nsketch/lustre/experimental/element/html.q\nsketch/lustre/experimental/element/html q","url":"sketch/lustre/experimental/element/html.html#q"},{"doc":"sketch/lustre/experimental/element/html","title":"q_","content":"pub fn q_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;q&gt;` HTML element indicates that the enclosed text is a short inline\n quotation. Most modern browsers implement this by surrounding the text in\n quotation marks. This element is intended for short quotations that don&#39;t\n require paragraph breaks; for long quotations use the `&lt;blockquote&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/q)\nSynonyms:\nsketch/lustre/experimental/element/html.q_\nsketch/lustre/experimental/element/html q_","url":"sketch/lustre/experimental/element/html.html#q_"},{"doc":"sketch/lustre/experimental/element/html","title":"rp","content":"pub fn rp(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;rp&gt;` HTML element is used to provide fall-back parentheses for\n browsers that do not support display of ruby annotations using the `&lt;ruby&gt;`\n element. One `&lt;rp&gt;` element should enclose each of the opening and closing\n parentheses that wrap the `&lt;rt&gt;` element that contains the annotation&#39;s text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/rp)\nSynonyms:\nsketch/lustre/experimental/element/html.rp\nsketch/lustre/experimental/element/html rp","url":"sketch/lustre/experimental/element/html.html#rp"},{"doc":"sketch/lustre/experimental/element/html","title":"rp_","content":"pub fn rp_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;rp&gt;` HTML element is used to provide fall-back parentheses for\n browsers that do not support display of ruby annotations using the `&lt;ruby&gt;`\n element. One `&lt;rp&gt;` element should enclose each of the opening and closing\n parentheses that wrap the `&lt;rt&gt;` element that contains the annotation&#39;s text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/rp)\nSynonyms:\nsketch/lustre/experimental/element/html.rp_\nsketch/lustre/experimental/element/html rp_","url":"sketch/lustre/experimental/element/html.html#rp_"},{"doc":"sketch/lustre/experimental/element/html","title":"rt","content":"pub fn rt(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;rt&gt;` HTML element specifies the ruby text component of a ruby\n annotation, which is used to provide pronunciation, translation, or\n transliteration information for East Asian typography. The `&lt;rt&gt;` element\n must always be contained within a `&lt;ruby&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/rt)\nSynonyms:\nsketch/lustre/experimental/element/html.rt\nsketch/lustre/experimental/element/html rt","url":"sketch/lustre/experimental/element/html.html#rt"},{"doc":"sketch/lustre/experimental/element/html","title":"rt_","content":"pub fn rt_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;rt&gt;` HTML element specifies the ruby text component of a ruby\n annotation, which is used to provide pronunciation, translation, or\n transliteration information for East Asian typography. The `&lt;rt&gt;` element\n must always be contained within a `&lt;ruby&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/rt)\nSynonyms:\nsketch/lustre/experimental/element/html.rt_\nsketch/lustre/experimental/element/html rt_","url":"sketch/lustre/experimental/element/html.html#rt_"},{"doc":"sketch/lustre/experimental/element/html","title":"ruby","content":"pub fn ruby(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ruby&gt;` HTML element represents small annotations that are rendered\n above, below, or next to base text, usually used for showing the\n pronunciation of East Asian characters. It can also be used for annotating\n other kinds of text, but this usage is less common.\n\n The term ruby originated as a\n [unit of measurement used by typesetters](https://en.wikipedia.org/wiki/Agate_(typography)),\n representing the smallest size that text can be printed on newsprint while\n remaining legible.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ruby)\nSynonyms:\nsketch/lustre/experimental/element/html.ruby\nsketch/lustre/experimental/element/html ruby","url":"sketch/lustre/experimental/element/html.html#ruby"},{"doc":"sketch/lustre/experimental/element/html","title":"ruby_","content":"pub fn ruby_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ruby&gt;` HTML element represents small annotations that are rendered\n above, below, or next to base text, usually used for showing the\n pronunciation of East Asian characters. It can also be used for annotating\n other kinds of text, but this usage is less common.\n\n The term ruby originated as a\n [unit of measurement used by typesetters](https://en.wikipedia.org/wiki/Agate_(typography)),\n representing the smallest size that text can be printed on newsprint while\n remaining legible.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ruby)\nSynonyms:\nsketch/lustre/experimental/element/html.ruby_\nsketch/lustre/experimental/element/html ruby_","url":"sketch/lustre/experimental/element/html.html#ruby_"},{"doc":"sketch/lustre/experimental/element/html","title":"s","content":"pub fn s(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;s&gt;` HTML element renders text with a strikethrough, or a line through\n it. Use the `&lt;s&gt;` element to represent things that are no longer relevant or\n no longer accurate. However, `&lt;s&gt;` is not appropriate when indicating\n document edits; for that, use the `&lt;del&gt;` and `&lt;ins&gt;` elements, as\n appropriate.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/s)\nSynonyms:\nsketch/lustre/experimental/element/html.s\nsketch/lustre/experimental/element/html s","url":"sketch/lustre/experimental/element/html.html#s"},{"doc":"sketch/lustre/experimental/element/html","title":"s_","content":"pub fn s_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;s&gt;` HTML element renders text with a strikethrough, or a line through\n it. Use the `&lt;s&gt;` element to represent things that are no longer relevant or\n no longer accurate. However, `&lt;s&gt;` is not appropriate when indicating\n document edits; for that, use the `&lt;del&gt;` and `&lt;ins&gt;` elements, as\n appropriate.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/s)\nSynonyms:\nsketch/lustre/experimental/element/html.s_\nsketch/lustre/experimental/element/html s_","url":"sketch/lustre/experimental/element/html.html#s_"},{"doc":"sketch/lustre/experimental/element/html","title":"samp","content":"pub fn samp(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;samp&gt;` HTML element is used to enclose inline text which represents\n sample (or quoted) output from a computer program. Its contents are\n typically rendered using the browser&#39;s default monospaced font (such as\n Courier or Lucida Console).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/samp)\nSynonyms:\nsketch/lustre/experimental/element/html.samp\nsketch/lustre/experimental/element/html samp","url":"sketch/lustre/experimental/element/html.html#samp"},{"doc":"sketch/lustre/experimental/element/html","title":"samp_","content":"pub fn samp_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;samp&gt;` HTML element is used to enclose inline text which represents\n sample (or quoted) output from a computer program. Its contents are\n typically rendered using the browser&#39;s default monospaced font (such as\n Courier or Lucida Console).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/samp)\nSynonyms:\nsketch/lustre/experimental/element/html.samp_\nsketch/lustre/experimental/element/html samp_","url":"sketch/lustre/experimental/element/html.html#samp_"},{"doc":"sketch/lustre/experimental/element/html","title":"script","content":"pub fn script(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;script&gt;` HTML element is used to embed executable code or data; this\n is typically used to embed or refer to JavaScript code. The `&lt;script&gt;`\n element can also be used with other languages, such as WebGL&#39;s GLSL shader\n programming language and JSON.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/script)\nSynonyms:\nsketch/lustre/experimental/element/html.script\nsketch/lustre/experimental/element/html script","url":"sketch/lustre/experimental/element/html.html#script"},{"doc":"sketch/lustre/experimental/element/html","title":"script_","content":"pub fn script_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;script&gt;` HTML element is used to embed executable code or data; this\n is typically used to embed or refer to JavaScript code. The `&lt;script&gt;`\n element can also be used with other languages, such as WebGL&#39;s GLSL shader\n programming language and JSON.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/script)\nSynonyms:\nsketch/lustre/experimental/element/html.script_\nsketch/lustre/experimental/element/html script_","url":"sketch/lustre/experimental/element/html.html#script_"},{"doc":"sketch/lustre/experimental/element/html","title":"search","content":"pub fn search(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;search&gt;` HTML element is a container representing the parts of the\n document or application with form controls or other content related to\n performing a search or filtering operation. The &lt;search&gt; element\n semantically identifies the purpose of the element&#39;s contents as having\n search or filtering capabilities. The search or filtering functionality can\n be for the website or application, the current web page or document, or the\n entire Internet or subsection thereof.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/search)\nSynonyms:\nsketch/lustre/experimental/element/html.search\nsketch/lustre/experimental/element/html search","url":"sketch/lustre/experimental/element/html.html#search"},{"doc":"sketch/lustre/experimental/element/html","title":"search_","content":"pub fn search_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;search&gt;` HTML element is a container representing the parts of the\n document or application with form controls or other content related to\n performing a search or filtering operation. The &lt;search&gt; element\n semantically identifies the purpose of the element&#39;s contents as having\n search or filtering capabilities. The search or filtering functionality can\n be for the website or application, the current web page or document, or the\n entire Internet or subsection thereof.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/search)\nSynonyms:\nsketch/lustre/experimental/element/html.search_\nsketch/lustre/experimental/element/html search_","url":"sketch/lustre/experimental/element/html.html#search_"},{"doc":"sketch/lustre/experimental/element/html","title":"section","content":"pub fn section(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;section&gt;` HTML element represents a generic standalone section of a\n document, which doesn&#39;t have a more specific semantic element to represent\n it. Sections should always have a heading, with very few exceptions.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/section)\nSynonyms:\nsketch/lustre/experimental/element/html.section\nsketch/lustre/experimental/element/html section","url":"sketch/lustre/experimental/element/html.html#section"},{"doc":"sketch/lustre/experimental/element/html","title":"section_","content":"pub fn section_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;section&gt;` HTML element represents a generic standalone section of a\n document, which doesn&#39;t have a more specific semantic element to represent\n it. Sections should always have a heading, with very few exceptions.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/section)\nSynonyms:\nsketch/lustre/experimental/element/html.section_\nsketch/lustre/experimental/element/html section_","url":"sketch/lustre/experimental/element/html.html#section_"},{"doc":"sketch/lustre/experimental/element/html","title":"select","content":"pub fn select(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;select&gt;` HTML element represents a control that provides a menu of options.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/select)\nSynonyms:\nsketch/lustre/experimental/element/html.select\nsketch/lustre/experimental/element/html select","url":"sketch/lustre/experimental/element/html.html#select"},{"doc":"sketch/lustre/experimental/element/html","title":"select_","content":"pub fn select_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;select&gt;` HTML element represents a control that provides a menu of options.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/select)\nSynonyms:\nsketch/lustre/experimental/element/html.select_\nsketch/lustre/experimental/element/html select_","url":"sketch/lustre/experimental/element/html.html#select_"},{"doc":"sketch/lustre/experimental/element/html","title":"slot","content":"pub fn slot(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;slot&gt;` HTML element—part of the Web Components technology suite—is a\n placeholder inside a web component that you can fill with your own markup,\n which lets you create separate DOM trees and present them together.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/slot)\nSynonyms:\nsketch/lustre/experimental/element/html.slot\nsketch/lustre/experimental/element/html slot","url":"sketch/lustre/experimental/element/html.html#slot"},{"doc":"sketch/lustre/experimental/element/html","title":"slot_","content":"pub fn slot_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;slot&gt;` HTML element—part of the Web Components technology suite—is a\n placeholder inside a web component that you can fill with your own markup,\n which lets you create separate DOM trees and present them together.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/slot)\nSynonyms:\nsketch/lustre/experimental/element/html.slot_\nsketch/lustre/experimental/element/html slot_","url":"sketch/lustre/experimental/element/html.html#slot_"},{"doc":"sketch/lustre/experimental/element/html","title":"small","content":"pub fn small(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;small&gt;` HTML element represents side-comments and small print, like\n `copyright and legal text, independent of its styled presentation. By\n default, it renders text within it one font-size smaller, such as from\n `small` to `x-small`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/small)\nSynonyms:\nsketch/lustre/experimental/element/html.small\nsketch/lustre/experimental/element/html small","url":"sketch/lustre/experimental/element/html.html#small"},{"doc":"sketch/lustre/experimental/element/html","title":"small_","content":"pub fn small_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;small&gt;` HTML element represents side-comments and small print, like\n `copyright and legal text, independent of its styled presentation. By\n default, it renders text within it one font-size smaller, such as from\n `small` to `x-small`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/small)\nSynonyms:\nsketch/lustre/experimental/element/html.small_\nsketch/lustre/experimental/element/html small_","url":"sketch/lustre/experimental/element/html.html#small_"},{"doc":"sketch/lustre/experimental/element/html","title":"source","content":"pub fn source(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;source&gt;` HTML element specifies one or more media resources for the\n `&lt;picture&gt;,` `&lt;audio&gt;,` and `&lt;video&gt;` elements. It is a\n [void element](https://developer.mozilla.org/docs/Glossary/Void_element),\n which means that it has no content and does not require a closing tag. This\n element is commonly used to offer the same media content in multiple file\n formats in order to provide compatibility with a broad range of browsers\n given their differing support for image file formats and media file formats.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/source)\nSynonyms:\nsketch/lustre/experimental/element/html.source\nsketch/lustre/experimental/element/html source","url":"sketch/lustre/experimental/element/html.html#source"},{"doc":"sketch/lustre/experimental/element/html","title":"source_","content":"pub fn source_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;source&gt;` HTML element specifies one or more media resources for the\n `&lt;picture&gt;,` `&lt;audio&gt;,` and `&lt;video&gt;` elements. It is a\n [void element](https://developer.mozilla.org/docs/Glossary/Void_element),\n which means that it has no content and does not require a closing tag. This\n element is commonly used to offer the same media content in multiple file\n formats in order to provide compatibility with a broad range of browsers\n given their differing support for image file formats and media file formats.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/source)\nSynonyms:\nsketch/lustre/experimental/element/html.source_\nsketch/lustre/experimental/element/html source_","url":"sketch/lustre/experimental/element/html.html#source_"},{"doc":"sketch/lustre/experimental/element/html","title":"span","content":"pub fn span(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;span&gt;` HTML element is a generic inline container for phrasing content,\n which does not inherently represent anything. It can be used to group\n elements for styling purposes (using the class or id attributes), or because\n they share attribute values, such as lang. It should be used only when no\n other semantic element is appropriate. `&lt;span&gt;` is very much like a `&lt;div&gt;`\n element, but `&lt;div&gt;` is a block-level element whereas a `&lt;span&gt;` is an\n inline-level element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/span)\nSynonyms:\nsketch/lustre/experimental/element/html.span\nsketch/lustre/experimental/element/html span","url":"sketch/lustre/experimental/element/html.html#span"},{"doc":"sketch/lustre/experimental/element/html","title":"span_","content":"pub fn span_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;span&gt;` HTML element is a generic inline container for phrasing content,\n which does not inherently represent anything. It can be used to group\n elements for styling purposes (using the class or id attributes), or because\n they share attribute values, such as lang. It should be used only when no\n other semantic element is appropriate. `&lt;span&gt;` is very much like a `&lt;div&gt;`\n element, but `&lt;div&gt;` is a block-level element whereas a `&lt;span&gt;` is an\n inline-level element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/span)\nSynonyms:\nsketch/lustre/experimental/element/html.span_\nsketch/lustre/experimental/element/html span_","url":"sketch/lustre/experimental/element/html.html#span_"},{"doc":"sketch/lustre/experimental/element/html","title":"strong","content":"pub fn strong(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;strong&gt;` HTML element indicates that its contents have strong\n importance, seriousness, or urgency. Browsers typically render the\n contents in bold type.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/strong)\nSynonyms:\nsketch/lustre/experimental/element/html.strong\nsketch/lustre/experimental/element/html strong","url":"sketch/lustre/experimental/element/html.html#strong"},{"doc":"sketch/lustre/experimental/element/html","title":"strong_","content":"pub fn strong_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;strong&gt;` HTML element indicates that its contents have strong\n importance, seriousness, or urgency. Browsers typically render the\n contents in bold type.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/strong)\nSynonyms:\nsketch/lustre/experimental/element/html.strong_\nsketch/lustre/experimental/element/html strong_","url":"sketch/lustre/experimental/element/html.html#strong_"},{"doc":"sketch/lustre/experimental/element/html","title":"style","content":"pub fn style(\n  attributes: List(Attribute(a)),\n  child: String,\n) -&gt; Element(a)\n The `&lt;style&gt;` HTML element contains style information for a document, or\n part of a document. It contains CSS, which is applied to the contents of\n the document containing the `&lt;style&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/style)\nSynonyms:\nsketch/lustre/experimental/element/html.style\nsketch/lustre/experimental/element/html style","url":"sketch/lustre/experimental/element/html.html#style"},{"doc":"sketch/lustre/experimental/element/html","title":"sub","content":"pub fn sub(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;sub&gt;` HTML element specifies inline text which should be displayed as\n subscript for solely typographical reasons. Subscripts are typically\n rendered with a lowered baseline using smaller text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/sub)\nSynonyms:\nsketch/lustre/experimental/element/html.sub\nsketch/lustre/experimental/element/html sub","url":"sketch/lustre/experimental/element/html.html#sub"},{"doc":"sketch/lustre/experimental/element/html","title":"sub_","content":"pub fn sub_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;sub&gt;` HTML element specifies inline text which should be displayed as\n subscript for solely typographical reasons. Subscripts are typically\n rendered with a lowered baseline using smaller text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/sub)\nSynonyms:\nsketch/lustre/experimental/element/html.sub_\nsketch/lustre/experimental/element/html sub_","url":"sketch/lustre/experimental/element/html.html#sub_"},{"doc":"sketch/lustre/experimental/element/html","title":"summary","content":"pub fn summary(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;summary&gt;` HTML element specifies a summary, caption, or legend for a\n `&lt;details&gt;` element&#39;s disclosure box. Clicking the `&lt;summary&gt;` element\n toggles the state of the parent `&lt;details&gt;` element open and closed.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/summary)\nSynonyms:\nsketch/lustre/experimental/element/html.summary\nsketch/lustre/experimental/element/html summary","url":"sketch/lustre/experimental/element/html.html#summary"},{"doc":"sketch/lustre/experimental/element/html","title":"summary_","content":"pub fn summary_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;summary&gt;` HTML element specifies a summary, caption, or legend for a\n `&lt;details&gt;` element&#39;s disclosure box. Clicking the `&lt;summary&gt;` element\n toggles the state of the parent `&lt;details&gt;` element open and closed.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/summary)\nSynonyms:\nsketch/lustre/experimental/element/html.summary_\nsketch/lustre/experimental/element/html summary_","url":"sketch/lustre/experimental/element/html.html#summary_"},{"doc":"sketch/lustre/experimental/element/html","title":"sup","content":"pub fn sup(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;sup&gt;` HTML element specifies inline text which is to be displayed as\n superscript for solely typographical reasons. Superscripts are usually\n rendered with a raised baseline using smaller text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/sup)\nSynonyms:\nsketch/lustre/experimental/element/html.sup\nsketch/lustre/experimental/element/html sup","url":"sketch/lustre/experimental/element/html.html#sup"},{"doc":"sketch/lustre/experimental/element/html","title":"sup_","content":"pub fn sup_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;sup&gt;` HTML element specifies inline text which is to be displayed as\n superscript for solely typographical reasons. Superscripts are usually\n rendered with a raised baseline using smaller text.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/sup)\nSynonyms:\nsketch/lustre/experimental/element/html.sup_\nsketch/lustre/experimental/element/html sup_","url":"sketch/lustre/experimental/element/html.html#sup_"},{"doc":"sketch/lustre/experimental/element/html","title":"svg","content":"pub fn svg(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;svg&gt;` SVG element is a container that defines a new coordinate system\n and viewport. It is used as the outermost element of SVG documents, but it\n can also be used to embed an SVG fragment inside an SVG or HTML document.\n\n &gt; The `xmlns` attribute is only required on the outermost `svg` element of\n &gt; SVG documents, or inside HTML documents with XML serialization. It is\n &gt; unnecessary for inner `svg` elements or inside HTML documents with\n &gt; HTML serialization.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/SVG/Element/svg)\nSynonyms:\nsketch/lustre/experimental/element/html.svg\nsketch/lustre/experimental/element/html svg","url":"sketch/lustre/experimental/element/html.html#svg"},{"doc":"sketch/lustre/experimental/element/html","title":"svg_","content":"pub fn svg_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;svg&gt;` SVG element is a container that defines a new coordinate system\n and viewport. It is used as the outermost element of SVG documents, but it\n can also be used to embed an SVG fragment inside an SVG or HTML document.\n\n &gt; The `xmlns` attribute is only required on the outermost `svg` element of\n &gt; SVG documents, or inside HTML documents with XML serialization. It is\n &gt; unnecessary for inner `svg` elements or inside HTML documents with\n &gt; HTML serialization.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/SVG/Element/svg)\nSynonyms:\nsketch/lustre/experimental/element/html.svg_\nsketch/lustre/experimental/element/html svg_","url":"sketch/lustre/experimental/element/html.html#svg_"},{"doc":"sketch/lustre/experimental/element/html","title":"table","content":"pub fn table(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;table&gt;` HTML element represents tabular data—that is, information\n presented in a two-dimensional table comprised of rows and columns of\n cells containing data.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/table)\nSynonyms:\nsketch/lustre/experimental/element/html.table\nsketch/lustre/experimental/element/html table","url":"sketch/lustre/experimental/element/html.html#table"},{"doc":"sketch/lustre/experimental/element/html","title":"table_","content":"pub fn table_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;table&gt;` HTML element represents tabular data—that is, information\n presented in a two-dimensional table comprised of rows and columns of\n cells containing data.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/table)\nSynonyms:\nsketch/lustre/experimental/element/html.table_\nsketch/lustre/experimental/element/html table_","url":"sketch/lustre/experimental/element/html.html#table_"},{"doc":"sketch/lustre/experimental/element/html","title":"tbody","content":"pub fn tbody(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;tbody&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the body of a table&#39;s (main) data.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tbody)\nSynonyms:\nsketch/lustre/experimental/element/html.tbody\nsketch/lustre/experimental/element/html tbody","url":"sketch/lustre/experimental/element/html.html#tbody"},{"doc":"sketch/lustre/experimental/element/html","title":"tbody_","content":"pub fn tbody_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;tbody&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the body of a table&#39;s (main) data.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tbody)\nSynonyms:\nsketch/lustre/experimental/element/html.tbody_\nsketch/lustre/experimental/element/html tbody_","url":"sketch/lustre/experimental/element/html.html#tbody_"},{"doc":"sketch/lustre/experimental/element/html","title":"td","content":"pub fn td(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;td&gt;` HTML element defines a cell of a table that contains data and\n may be used as a child of the `&lt;tr&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/td)\nSynonyms:\nsketch/lustre/experimental/element/html.td\nsketch/lustre/experimental/element/html td","url":"sketch/lustre/experimental/element/html.html#td"},{"doc":"sketch/lustre/experimental/element/html","title":"td_","content":"pub fn td_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;td&gt;` HTML element defines a cell of a table that contains data and\n may be used as a child of the `&lt;tr&gt;` element.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/td)\nSynonyms:\nsketch/lustre/experimental/element/html.td_\nsketch/lustre/experimental/element/html td_","url":"sketch/lustre/experimental/element/html.html#td_"},{"doc":"sketch/lustre/experimental/element/html","title":"template","content":"pub fn template(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;template&gt;` HTML element serves as a mechanism for holding HTML\n fragments, which can either be used later via JavaScript or generated\n immediately into shadow DOM.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/template)\nSynonyms:\nsketch/lustre/experimental/element/html.template\nsketch/lustre/experimental/element/html template","url":"sketch/lustre/experimental/element/html.html#template"},{"doc":"sketch/lustre/experimental/element/html","title":"template_","content":"pub fn template_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;template&gt;` HTML element serves as a mechanism for holding HTML\n fragments, which can either be used later via JavaScript or generated\n immediately into shadow DOM.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/template)\nSynonyms:\nsketch/lustre/experimental/element/html.template_\nsketch/lustre/experimental/element/html template_","url":"sketch/lustre/experimental/element/html.html#template_"},{"doc":"sketch/lustre/experimental/element/html","title":"text","content":"pub fn text(content: String) -&gt; Element(a)\n The `Text` interface represents a text node in a DOM tree.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/API/Text)\nSynonyms:\nsketch/lustre/experimental/element/html.text\nsketch/lustre/experimental/element/html text","url":"sketch/lustre/experimental/element/html.html#text"},{"doc":"sketch/lustre/experimental/element/html","title":"textarea","content":"pub fn textarea(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;textarea&gt;` HTML element represents a multi-line plain-text editing\n control, useful when you want to allow users to enter a sizeable amount of\n free-form text, for example a comment on a review or feedback form.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/textarea)\nSynonyms:\nsketch/lustre/experimental/element/html.textarea\nsketch/lustre/experimental/element/html textarea","url":"sketch/lustre/experimental/element/html.html#textarea"},{"doc":"sketch/lustre/experimental/element/html","title":"textarea_","content":"pub fn textarea_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;textarea&gt;` HTML element represents a multi-line plain-text editing\n control, useful when you want to allow users to enter a sizeable amount of\n free-form text, for example a comment on a review or feedback form.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/textarea)\nSynonyms:\nsketch/lustre/experimental/element/html.textarea_\nsketch/lustre/experimental/element/html textarea_","url":"sketch/lustre/experimental/element/html.html#textarea_"},{"doc":"sketch/lustre/experimental/element/html","title":"tfoot","content":"pub fn tfoot(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;tfoot&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the foot of a table with\n information about the table&#39;s columns. This is usually a summary of the\n columns, e.g., a sum of the given numbers in a column.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tfoot)\nSynonyms:\nsketch/lustre/experimental/element/html.tfoot\nsketch/lustre/experimental/element/html tfoot","url":"sketch/lustre/experimental/element/html.html#tfoot"},{"doc":"sketch/lustre/experimental/element/html","title":"tfoot_","content":"pub fn tfoot_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;tfoot&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the foot of a table with\n information about the table&#39;s columns. This is usually a summary of the\n columns, e.g., a sum of the given numbers in a column.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tfoot)\nSynonyms:\nsketch/lustre/experimental/element/html.tfoot_\nsketch/lustre/experimental/element/html tfoot_","url":"sketch/lustre/experimental/element/html.html#tfoot_"},{"doc":"sketch/lustre/experimental/element/html","title":"th","content":"pub fn th(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;th&gt;` HTML element defines a cell as the header of a group of table\n cells and may be used as a child of the `&lt;tr&gt;` element. The exact nature\n of this group is defined by the `scope` and `headers` attributes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/th)\nSynonyms:\nsketch/lustre/experimental/element/html.th\nsketch/lustre/experimental/element/html th","url":"sketch/lustre/experimental/element/html.html#th"},{"doc":"sketch/lustre/experimental/element/html","title":"th_","content":"pub fn th_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;th&gt;` HTML element defines a cell as the header of a group of table\n cells and may be used as a child of the `&lt;tr&gt;` element. The exact nature\n of this group is defined by the `scope` and `headers` attributes.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/th)\nSynonyms:\nsketch/lustre/experimental/element/html.th_\nsketch/lustre/experimental/element/html th_","url":"sketch/lustre/experimental/element/html.html#th_"},{"doc":"sketch/lustre/experimental/element/html","title":"thead","content":"pub fn thead(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;thead&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the head of a table with\n information about the table&#39;s columns. This is usually in the form of\n column headers (`&lt;th&gt;` elements).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/thead)\nSynonyms:\nsketch/lustre/experimental/element/html.thead\nsketch/lustre/experimental/element/html thead","url":"sketch/lustre/experimental/element/html.html#thead"},{"doc":"sketch/lustre/experimental/element/html","title":"thead_","content":"pub fn thead_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;thead&gt;` HTML element encapsulates a set of table rows (`&lt;tr&gt;`\n elements), indicating that they comprise the head of a table with\n information about the table&#39;s columns. This is usually in the form of\n column headers (`&lt;th&gt;` elements).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/thead)\nSynonyms:\nsketch/lustre/experimental/element/html.thead_\nsketch/lustre/experimental/element/html thead_","url":"sketch/lustre/experimental/element/html.html#thead_"},{"doc":"sketch/lustre/experimental/element/html","title":"time","content":"pub fn time(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;time&gt;` HTML element represents a specific period in time. It may\n include the datetime attribute to translate dates into machine-readable\n format, allowing for better search engine results or custom features such\n as reminders.\n\n It may represent one of the following:\n - A time on a 24-hour clock.\n - A precise date in the [Gregorian calendar](https://en.wikipedia.org/wiki/Gregorian_calendar)\n   (with optional time and timezone information).\n - [A valid time duration](https://html.spec.whatwg.org/multipage/common-microsyntaxes.html#valid-duration-string).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/time)\nSynonyms:\nsketch/lustre/experimental/element/html.time\nsketch/lustre/experimental/element/html time","url":"sketch/lustre/experimental/element/html.html#time"},{"doc":"sketch/lustre/experimental/element/html","title":"time_","content":"pub fn time_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;time&gt;` HTML element represents a specific period in time. It may\n include the datetime attribute to translate dates into machine-readable\n format, allowing for better search engine results or custom features such\n as reminders.\n\n It may represent one of the following:\n - A time on a 24-hour clock.\n - A precise date in the [Gregorian calendar](https://en.wikipedia.org/wiki/Gregorian_calendar)\n   (with optional time and timezone information).\n - [A valid time duration](https://html.spec.whatwg.org/multipage/common-microsyntaxes.html#valid-duration-string).\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/time)\nSynonyms:\nsketch/lustre/experimental/element/html.time_\nsketch/lustre/experimental/element/html time_","url":"sketch/lustre/experimental/element/html.html#time_"},{"doc":"sketch/lustre/experimental/element/html","title":"title","content":"pub fn title(\n  attributes: List(Attribute(a)),\n  title: String,\n) -&gt; Element(a)\n The `&lt;title&gt;` HTML element defines the document&#39;s title that is shown in a\n browser&#39;s title bar or a page&#39;s tab. It only contains text; tags within\n the element are ignored.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/title)\nSynonyms:\nsketch/lustre/experimental/element/html.title\nsketch/lustre/experimental/element/html title","url":"sketch/lustre/experimental/element/html.html#title"},{"doc":"sketch/lustre/experimental/element/html","title":"tr","content":"pub fn tr(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;tr&gt;` HTML element defines a row of cells in a table. The row&#39;s cells\n can then be established using a mix of `&lt;td&gt;` (data cell) and `&lt;th&gt;`\n (header cell) elements.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tr)\nSynonyms:\nsketch/lustre/experimental/element/html.tr\nsketch/lustre/experimental/element/html tr","url":"sketch/lustre/experimental/element/html.html#tr"},{"doc":"sketch/lustre/experimental/element/html","title":"tr_","content":"pub fn tr_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;tr&gt;` HTML element defines a row of cells in a table. The row&#39;s cells\n can then be established using a mix of `&lt;td&gt;` (data cell) and `&lt;th&gt;`\n (header cell) elements.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/tr)\nSynonyms:\nsketch/lustre/experimental/element/html.tr_\nsketch/lustre/experimental/element/html tr_","url":"sketch/lustre/experimental/element/html.html#tr_"},{"doc":"sketch/lustre/experimental/element/html","title":"track","content":"pub fn track(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;track&gt;` HTML element is used as a child of the media elements,\n `&lt;audio&gt;` and `&lt;video&gt;`. Each track element lets you specify a timed text\n track (or time-based data) that can be displayed in parallel with the media\n element, for example to overlay subtitles or closed captions on top of a\n video or alongside audio tracks.\n\n Multiple tracks can be specified for a media element, containing different\n kinds of timed text data, or timed text data that has been translated for\n different locales. The data that is used will either be the track that has\n been set to be the default, or a kind and translation based on user\n preferences.\n\n The tracks are formatted in [WebVTT format](https://developer.mozilla.org/docs/Web/API/WebVTT_API)\n (`.vtt` files) — Web Video Text Tracks.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/track)\nSynonyms:\nsketch/lustre/experimental/element/html.track\nsketch/lustre/experimental/element/html track","url":"sketch/lustre/experimental/element/html.html#track"},{"doc":"sketch/lustre/experimental/element/html","title":"track_","content":"pub fn track_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;track&gt;` HTML element is used as a child of the media elements,\n `&lt;audio&gt;` and `&lt;video&gt;`. Each track element lets you specify a timed text\n track (or time-based data) that can be displayed in parallel with the media\n element, for example to overlay subtitles or closed captions on top of a\n video or alongside audio tracks.\n\n Multiple tracks can be specified for a media element, containing different\n kinds of timed text data, or timed text data that has been translated for\n different locales. The data that is used will either be the track that has\n been set to be the default, or a kind and translation based on user\n preferences.\n\n The tracks are formatted in [WebVTT format](https://developer.mozilla.org/docs/Web/API/WebVTT_API)\n (`.vtt` files) — Web Video Text Tracks.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/track)\nSynonyms:\nsketch/lustre/experimental/element/html.track_\nsketch/lustre/experimental/element/html track_","url":"sketch/lustre/experimental/element/html.html#track_"},{"doc":"sketch/lustre/experimental/element/html","title":"u","content":"pub fn u(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;u&gt;` HTML element represents a span of inline text which should be\n rendered in a way that indicates that it has a non-textual annotation. This\n is rendered by default as a single solid underline, but may be altered\n using CSS.\n\n &gt; This element used to be called the &quot;Underline&quot; element in older versions\n &gt; of HTML, and is still sometimes misused in this way. To underline text,\n &gt; you should instead apply a style that includes the CSS `text-decoration`\n &gt; property set to `underline`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/u)\nSynonyms:\nsketch/lustre/experimental/element/html.u\nsketch/lustre/experimental/element/html u","url":"sketch/lustre/experimental/element/html.html#u"},{"doc":"sketch/lustre/experimental/element/html","title":"u_","content":"pub fn u_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;u&gt;` HTML element represents a span of inline text which should be\n rendered in a way that indicates that it has a non-textual annotation. This\n is rendered by default as a single solid underline, but may be altered\n using CSS.\n\n &gt; This element used to be called the &quot;Underline&quot; element in older versions\n &gt; of HTML, and is still sometimes misused in this way. To underline text,\n &gt; you should instead apply a style that includes the CSS `text-decoration`\n &gt; property set to `underline`.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/u)\nSynonyms:\nsketch/lustre/experimental/element/html.u_\nsketch/lustre/experimental/element/html u_","url":"sketch/lustre/experimental/element/html.html#u_"},{"doc":"sketch/lustre/experimental/element/html","title":"ul","content":"pub fn ul(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ul&gt;` HTML element represents an unordered list of items, typically\n rendered as a bulleted list.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ul)\nSynonyms:\nsketch/lustre/experimental/element/html.ul\nsketch/lustre/experimental/element/html ul","url":"sketch/lustre/experimental/element/html.html#ul"},{"doc":"sketch/lustre/experimental/element/html","title":"ul_","content":"pub fn ul_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;ul&gt;` HTML element represents an unordered list of items, typically\n rendered as a bulleted list.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/ul)\nSynonyms:\nsketch/lustre/experimental/element/html.ul_\nsketch/lustre/experimental/element/html ul_","url":"sketch/lustre/experimental/element/html.html#ul_"},{"doc":"sketch/lustre/experimental/element/html","title":"var","content":"pub fn var(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;var&gt;` HTML element represents the name of a variable in a mathematical\n expression or a programming context. It&#39;s typically presented using an\n italicized version of the current typeface, although that behavior is\n browser-dependent.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/var)\nSynonyms:\nsketch/lustre/experimental/element/html.var\nsketch/lustre/experimental/element/html var","url":"sketch/lustre/experimental/element/html.html#var"},{"doc":"sketch/lustre/experimental/element/html","title":"var_","content":"pub fn var_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;var&gt;` HTML element represents the name of a variable in a mathematical\n expression or a programming context. It&#39;s typically presented using an\n italicized version of the current typeface, although that behavior is\n browser-dependent.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/var)\nSynonyms:\nsketch/lustre/experimental/element/html.var_\nsketch/lustre/experimental/element/html var_","url":"sketch/lustre/experimental/element/html.html#var_"},{"doc":"sketch/lustre/experimental/element/html","title":"video","content":"pub fn video(\n  class: Class,\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;video&gt;` HTML element embeds a media player which supports video\n playback into the document. You can use `&lt;video&gt;` for audio content as\n well, but the `&lt;audio&gt;` element may provide a more appropriate user experience.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/video)\nSynonyms:\nsketch/lustre/experimental/element/html.video\nsketch/lustre/experimental/element/html video","url":"sketch/lustre/experimental/element/html.html#video"},{"doc":"sketch/lustre/experimental/element/html","title":"video_","content":"pub fn video_(\n  attributes: List(Attribute(a)),\n  children: List(Element(a)),\n) -&gt; Element(a)\n The `&lt;video&gt;` HTML element embeds a media player which supports video\n playback into the document. You can use `&lt;video&gt;` for audio content as\n well, but the `&lt;audio&gt;` element may provide a more appropriate user experience.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/video)\nSynonyms:\nsketch/lustre/experimental/element/html.video_\nsketch/lustre/experimental/element/html video_","url":"sketch/lustre/experimental/element/html.html#video_"},{"doc":"sketch/lustre/experimental/element/html","title":"wbr","content":"pub fn wbr(\n  class: Class,\n  attributes: List(Attribute(a)),\n) -&gt; Element(a)\n The `&lt;wbr&gt;` HTML element represents a word break opportunity—a position\n within text where the browser may optionally break a line, though its\n line-breaking rules would not otherwise create a break at that location.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/wbr)\nSynonyms:\nsketch/lustre/experimental/element/html.wbr\nsketch/lustre/experimental/element/html wbr","url":"sketch/lustre/experimental/element/html.html#wbr"},{"doc":"sketch/lustre/experimental/element/html","title":"wbr_","content":"pub fn wbr_(attributes: List(Attribute(a))) -&gt; Element(a)\n The `&lt;wbr&gt;` HTML element represents a word break opportunity—a position\n within text where the browser may optionally break a line, though its\n line-breaking rules would not otherwise create a break at that location.\n\n ---\n\n [MDN Reference](https://developer.mozilla.org/docs/Web/HTML/Element/wbr)\nSynonyms:\nsketch/lustre/experimental/element/html.wbr_\nsketch/lustre/experimental/element/html wbr_","url":"sketch/lustre/experimental/element/html.html#wbr_"},{"doc":"sketch/lustre/experimental/element/html","title":"sketch/lustre/experimental/element/html","content":" This module is a drop-in replacement for `lustre/element/html`. Just\n use the new functions, and everything will automagically be styled.\n Every stylable node has two functions: `[node]` and `[node]_`, the former\n applying a style, while the latter does not accept style, in case you don&#39;t\n need to style a node.","url":"sketch/lustre/experimental/element/html.html"}]);